@@ -134,7 +134,7 @@ static size_t rdfa_init_base(
 {
    char* head_end = NULL;
    size_t offset = context->wb_position;
-   int needed_size = (offset + bytes_read) - *working_buffer_size;
+   size_t needed_size = (offset + bytes_read) - *working_buffer_size;
 
    // search for the end of <head>, stop if <head> was found
 
@@ -1245,13 +1245,13 @@ static int rdfa_process_doctype(rdfacontext* context, size_t* bytes)
    {
       char* new_doctype_buffer = NULL;
       size_t new_doctype_buffer_length = 0;
-      char* doctype_end = index(doctype_position, '>');
+      char* doctype_end = strchr(doctype_position, '>');
 
       // make sure that the end of the doctype declaration can be found
       if(doctype_end != NULL)
       {
-         int bytes_to_copy = 0;
-         int total_bytes = 0;
+         size_t bytes_to_copy = 0;
+         size_t total_bytes = 0;
 
          // create the new doctype buffer
          bytes_to_copy = doctype_position - doctype_buffer;
@@ -1293,8 +1293,8 @@ static int rdfa_process_doctype(rdfacontext* context, size_t* bytes)
 
       if(html_position != NULL)
       {
-         int bytes_to_copy = 0;
-         int total_bytes = 0;
+         size_t bytes_to_copy = 0;
+         size_t total_bytes = 0;
 
          // create the new doctype buffer
          bytes_to_copy = html_position - doctype_buffer;
