@@ -65,7 +65,11 @@ const char * const raptor_home_url_string = "http://librdf.org/raptor/";
  *
  * See also #raptor_version_decimal.
  */
-const char * const raptor_version_string = VERSION;
+const char * const raptor_version_string = VERSION
+#ifdef GIT_VERSION
+" GIT " GIT_VERSION
+#endif
+;
 
 /**
  * raptor_version_major:
@@ -129,7 +133,7 @@ raptor_new_world_internal(unsigned int version_decimal)
     return NULL;
   }
   
-  world = (raptor_world*)RAPTOR_CALLOC(raptor_world, sizeof(*world), 1);
+  world = RAPTOR_CALLOC(raptor_world*, 1, sizeof(*world));
   if(world) {
     world->magic = RAPTOR2_WORLD_MAGIC;
     
@@ -226,7 +230,7 @@ raptor_free_world(raptor_world* world)
     return;
 
   if(world->default_generate_bnodeid_handler_prefix)
-    RAPTOR_FREE(cstring, world->default_generate_bnodeid_handler_prefix);
+    RAPTOR_FREE(char*, world->default_generate_bnodeid_handler_prefix);
 
 #ifdef RAPTOR_XML_LIBXML
   raptor_libxml_finish(world);
@@ -284,35 +288,32 @@ raptor_world_default_generate_bnodeid_handler(void *user_data,
   raptor_world *world = (raptor_world*)user_data;
   int id;
   unsigned char *buffer;
-  int length;
-  int tmpid;
+  const char* prefix;
+  unsigned int prefix_length;
+  int id_length;
 
   if(user_bnodeid)
     return user_bnodeid;
 
   id = ++world->default_generate_bnodeid_handler_base;
 
-  tmpid = id;
-  length = 2; /* min length 1 + \0 */
-  while(tmpid /= 10)
-    length++;
+  id_length = raptor_format_integer(NULL, 0, id, /* base */ 10, -1, '\0');
 
-  if(world->default_generate_bnodeid_handler_prefix)
-    length += world->default_generate_bnodeid_handler_prefix_length;
-  else
-    length += 5; /* strlen("genid") */
-  
-  buffer = (unsigned char*)RAPTOR_MALLOC(cstring, length);
+  if(world->default_generate_bnodeid_handler_prefix) {
+    prefix = world->default_generate_bnodeid_handler_prefix;
+    prefix_length = world->default_generate_bnodeid_handler_prefix_length;
+  } else {
+    prefix = "genid";
+    prefix_length = 5; /* strlen("genid") */
+  }
+
+  buffer = RAPTOR_MALLOC(unsigned char*, id_length + prefix_length + 1);
   if(!buffer)
     return NULL;
 
-  if(world->default_generate_bnodeid_handler_prefix) {
-    memcpy(buffer, world->default_generate_bnodeid_handler_prefix,
-           world->default_generate_bnodeid_handler_prefix_length);
-    sprintf((char*)buffer + world->default_generate_bnodeid_handler_prefix_length,
-            "%d", id);
-  } else 
-    sprintf((char*)buffer, "genid%d", id);
+  memcpy(buffer, prefix, prefix_length);
+  (void)raptor_format_integer(RAPTOR_GOOD_CAST(char*, &buffer[prefix_length]),
+                              id_length + 1, id, /* base */ 10,-1, '\0');
 
   return buffer;
 }
@@ -371,15 +372,15 @@ raptor_world_set_generate_bnodeid_parameters(raptor_world* world,
                                              char *prefix, int base)
 {
   char *prefix_copy = NULL;
-  size_t length = 0;
+  unsigned int length = 0;
 
   if(--base < 0)
     base = 0;
 
   if(prefix) {
-    length = strlen(prefix);
+    length = RAPTOR_BAD_CAST(unsigned int, strlen(prefix));
     
-    prefix_copy = (char*)RAPTOR_MALLOC(cstring, length + 1);
+    prefix_copy = RAPTOR_MALLOC(char*, length + 1);
     if(!prefix_copy)
       return;
 
@@ -387,7 +388,7 @@ raptor_world_set_generate_bnodeid_parameters(raptor_world* world,
   }
   
   if(world->default_generate_bnodeid_handler_prefix)
-    RAPTOR_FREE(cstring, world->default_generate_bnodeid_handler_prefix);
+    RAPTOR_FREE(char*, world->default_generate_bnodeid_handler_prefix);
 
   world->default_generate_bnodeid_handler_prefix = prefix_copy;
   world->default_generate_bnodeid_handler_prefix_length = length;
@@ -511,137 +512,6 @@ raptor_world_set_log_handler(raptor_world *world, void *user_data,
 }
 
 
-/* 
- * Thanks to the patch in this Debian bug for the solution
- * to the crash inside vsnprintf on some architectures.
- *
- * "reuse of args inside the while(1) loop is in violation of the
- * specs and only happens to work by accident on other systems."
- *
- * http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=104325 
- */
-
-#ifndef va_copy
-#ifdef __va_copy
-#define va_copy(dest,src) __va_copy(dest,src)
-#else
-#define va_copy(dest,src) (dest) = (src)
-#endif
-#endif
-
-
-#ifdef CHECK_VSNPRINTF_RUNTIME
-static int vsnprintf_checked = -1;
-
-static int
-vsnprint_check_is_c99(const char *s, ...)
-{
-  char buffer[32];
-  va_list args;
-  int r;
-  va_start(args, s);
-  r = vsnprintf(buffer, 5, s, args);
-  va_end(args);
-
-  return (r == 7);
-}
-
-static int
-vsnprintf_is_c99(void)
-{
-  if(vsnprintf_checked < 0)
-    vsnprintf_checked = vsnprint_check_is_c99("1234567");
-  return vsnprintf_checked;
-}
-#endif
-
-
-#define VSNPRINTF_C99_BLOCK \
-do { \
-  /* copy for re-use */ \
-  va_copy(args_copy, arguments); \
-  len = vsnprintf(empty_buffer, 1, message, args_copy)+1; \
-  va_end(args_copy); \
- \
-  if(len <= 0) \
-    return NULL; \
-   \
-  buffer = (char*)RAPTOR_MALLOC(cstring, len); \
-  if(buffer) { \
-    /* copy for re-use */ \
-    va_copy(args_copy, arguments); \
-    vsnprintf(buffer, len, message, args_copy); \
-    va_end(args_copy); \
-  } \
-} while(0)
-
-#define VSNPRINTF_NOT_C99_BLOCK \
-do { \
-  /* This vsnprintf doesn't return number of bytes required */ \
-  int size = 2; \
-       \
-  while(1) { \
-    buffer = (char*)RAPTOR_MALLOC(cstring, size+1); \
-    if(!buffer) \
-      break; \
-     \
-    /* copy for re-use */ \
-    va_copy(args_copy, arguments); \
-    len = vsnprintf(buffer, size, message, args_copy); \
-    va_end(args_copy); \
- \
-    /* On windows, vsnprintf() returns -1 if the buffer does not fit. \
-     * If the buffer exactly fits the string without a NULL \
-     * terminator, it returns the string length and it ends up with \
-     * an unterminated string.  The added check makes sure the string \
-     * returned is terminated - otherwise more buffer space is \
-     * allocated and the while() loop retries. \
-    */ \
-    if((len >= 0) && (buffer[len] == '\0')) \
-      break; \
-    RAPTOR_FREE(cstring, buffer); \
-    size += 4; \
-  } \
-} while(0)
-
-
-/**
- * raptor_vsnprintf:
- * @message: printf-style format string
- * @arguments: variable arguments list
- * 
- * Format output for a variable arguments list.
- *
- * This is a wrapper around system versions of vsnprintf with
- * different call and return conventions.
- * 
- * Return value: a newly allocated string as the format result or NULL on failure
- **/
-char*
-raptor_vsnprintf(const char *message, va_list arguments) 
-{
-  char empty_buffer[1];
-  int len;
-  char *buffer = NULL;
-  va_list args_copy;
-
-#ifdef CHECK_VSNPRINTF_RUNTIME
-  if(vsnprintf_is_c99())
-    VSNPRINTF_C99_BLOCK ;
-  else
-    VSNPRINTF_NOT_C99_BLOCK ;
-#else
-#ifdef HAVE_C99_VSNPRINTF
-  VSNPRINTF_C99_BLOCK ;
-#else
-  VSNPRINTF_NOT_C99_BLOCK ;
-#endif
-#endif
-
-  return buffer;
-}
-
-
 /**
  * raptor_basename:
  * @name: path
@@ -781,7 +651,7 @@ raptor_free_memory(void *ptr)
 void*
 raptor_alloc_memory(size_t size)
 {
-  return RAPTOR_MALLOC(void, size);
+  return RAPTOR_MALLOC(void*, size);
 }
 
 
@@ -808,7 +678,7 @@ raptor_alloc_memory(size_t size)
 void*
 raptor_calloc_memory(size_t nmemb, size_t size)
 {
-  return RAPTOR_CALLOC(void, nmemb, size);
+  return RAPTOR_CALLOC(void*, nmemb, size);
 }
 
 
