@@ -187,7 +187,7 @@ raptor_grddl_xsltGenericError_handler(void *user_data, const char *msg, ...)
   raptor_parser* rdf_parser = (raptor_parser*)user_data;
   va_list arguments;
   size_t msg_len;
-  int length;
+  size_t length;
   char *nmsg;
 
   if(!msg || *msg == '\n')
@@ -200,7 +200,7 @@ raptor_grddl_xsltGenericError_handler(void *user_data, const char *msg, ...)
 #define PREFIX "libxslt error: "
 #define PREFIX_LENGTH 15
   length = PREFIX_LENGTH + msg_len + 1;
-  nmsg = (char*)RAPTOR_MALLOC(cstring, length);
+  nmsg = RAPTOR_MALLOC(char*, length);
   if(nmsg) {
     memcpy(nmsg, PREFIX, PREFIX_LENGTH);
     memcpy(nmsg + PREFIX_LENGTH, msg, msg_len + 1);
@@ -210,7 +210,7 @@ raptor_grddl_xsltGenericError_handler(void *user_data, const char *msg, ...)
 
   raptor_parser_error_varargs(rdf_parser, nmsg ? nmsg : msg, arguments);
   if(nmsg)
-    RAPTOR_FREE(cstring, nmsg);
+    RAPTOR_FREE(char*, nmsg);
 
   va_end(arguments);
 }
@@ -222,8 +222,7 @@ raptor_new_xml_context(raptor_world* world, raptor_uri* uri,
 {
   grddl_xml_context* xml_context;
 
-  xml_context = (grddl_xml_context*)RAPTOR_MALLOC(xml_context,
-                                                  sizeof(*xml_context));
+  xml_context = RAPTOR_MALLOC(grddl_xml_context*, sizeof(*xml_context));
   if(uri)
     uri = raptor_uri_copy(uri);
   if(base_uri)
@@ -354,7 +353,7 @@ raptor_grddl_parse_terminate(raptor_parser *rdf_parser)
   }
 
   if(grddl_parser->content_type)
-    RAPTOR_FREE(cstring, grddl_parser->content_type);
+    RAPTOR_FREE(char*, grddl_parser->content_type);
 
   if(grddl_parser->sb)
     raptor_free_stringbuffer(grddl_parser->sb);
@@ -490,7 +489,7 @@ raptor_grddl_add_transform_xml_context(raptor_grddl_parser_context* grddl_parser
   raptor_uri* uri = xml_context->uri;
   int size;
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_DEBUG2("Found document transformation URI '%s'\n",
                 raptor_uri_as_string(uri));
 #endif
@@ -500,7 +499,7 @@ raptor_grddl_add_transform_xml_context(raptor_grddl_parser_context* grddl_parser
     grddl_xml_context* xc;
     xc = (grddl_xml_context*)raptor_sequence_get_at(grddl_parser->doc_transform_uris, i);
     if(raptor_uri_equals(uri, xc->uri)) {
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_DEBUG2("Already seen XSLT URI '%s'\n", raptor_uri_as_string(uri));
 #endif
       grddl_free_xml_context(grddl_parser->world, xml_context);
@@ -533,13 +532,13 @@ raptor_grddl_filter_triples(void *user_data, raptor_statement *statement)
      !statement->object->type == RAPTOR_TERM_TYPE_URI)
     return;
 
-#if RAPTOR_DEBUG > 2
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 2
   RAPTOR_DEBUG2("Parser %p: Relaying statement: ", rdf_parser);
   raptor_statement_print(statement, stderr);
   fputc('\n', stderr);
 #endif
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_DEBUG3("Parser %p: Checking against %d profile URIs\n", 
                 rdf_parser, raptor_sequence_size(grddl_parser->profile_uris));
 #endif
@@ -570,7 +569,7 @@ raptor_grddl_filter_triples(void *user_data, raptor_statement *statement)
        raptor_uri_equals(statement->predicate->value.uri, predicate_uri)) {
       raptor_uri* uri = statement->object->value.uri;
       
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_DEBUG4("Parser %p: Matches profile URI #%d '%s'\n",
                     rdf_parser, i, raptor_uri_as_string(profile_uri));
 #endif
@@ -579,7 +578,7 @@ raptor_grddl_filter_triples(void *user_data, raptor_statement *statement)
                                                rdf_parser->base_uri);
       raptor_grddl_add_transform_xml_context(grddl_parser, new_xml_context);
     } else {
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_DEBUG4("Parser %p: Failed to match profile URI #%d '%s'\n",
                     rdf_parser, i, raptor_uri_as_string(profile_uri));
 #endif
@@ -724,7 +723,7 @@ raptor_grddl_run_grddl_transform_doc(raptor_parser* rdf_parser,
    * url: (optional)
    *   http://www.w3.org/2001/sw/grddl-wg/td/RDFa2RDFXML.xsl
    */
-  quoted_base_uri = (char*)RAPTOR_MALLOC(cstring, base_uri_len + 3);
+  quoted_base_uri = RAPTOR_MALLOC(char*, base_uri_len + 3);
   quoted_base_uri[0] = '\'';
   memcpy(quoted_base_uri + 1, (const char*)base_uri_string, base_uri_len);
   quoted_base_uri[base_uri_len + 1] = '\'';
@@ -828,7 +827,7 @@ raptor_grddl_run_grddl_transform_doc(raptor_parser* rdf_parser,
     xsltFreeTransformContext(userCtxt);
   
   if(quoted_base_uri)
-    RAPTOR_FREE(cstring, quoted_base_uri);
+    RAPTOR_FREE(char*, quoted_base_uri);
   
   if(doc_txt)    
     xmlFree(doc_txt);
@@ -859,7 +858,7 @@ raptor_grddl_uri_xml_parse_bytes(raptor_www* www,
                                  const void *ptr, size_t size, size_t nmemb)
 {
   raptor_grddl_xml_parse_bytes_context* xpbc;
-  int len = size*nmemb;
+  size_t len = size * nmemb;
   int rc = 0;
   
   xpbc = (raptor_grddl_xml_parse_bytes_context*)userdata;
@@ -868,7 +867,7 @@ raptor_grddl_uri_xml_parse_bytes(raptor_www* www,
     xmlParserCtxtPtr xc;
     
     xc = xmlCreatePushParserCtxt(NULL, NULL,
-                                 (const char*)ptr, len,
+                                 (const char*)ptr, RAPTOR_BAD_CAST(int, len),
                                  (const char*)raptor_uri_as_string(xpbc->base_uri));
     if(!xc)
       rc = 1;
@@ -888,7 +887,7 @@ raptor_grddl_uri_xml_parse_bytes(raptor_www* www,
     }
     xpbc->xc = xc;
   } else
-    rc = xmlParseChunk(xpbc->xc, (const char*)ptr, len, 0);
+    rc = xmlParseChunk(xpbc->xc, (const char*)ptr, RAPTOR_BAD_CAST(int, len), 0);
 
   if(rc)
     raptor_parser_error(xpbc->rdf_parser, "XML Parsing failed");
@@ -929,7 +928,7 @@ raptor_grddl_fetch_uri(raptor_parser* rdf_parser,
     accept_h = raptor_parser_get_accept_header(rdf_parser);
     if(accept_h) {
       raptor_www_set_http_accept(www, accept_h);
-      RAPTOR_FREE(cstring, accept_h);
+      RAPTOR_FREE(char*, accept_h);
     }
   }
   if(rdf_parser->uri_filter)
@@ -984,7 +983,7 @@ raptor_grddl_run_grddl_transform_uri(raptor_parser* rdf_parser,
    */
   xpbc.xc = NULL;
   xpbc.rdf_parser = rdf_parser;
-  xpbc.base_uri = xslt_uri;
+  xpbc.base_uri = base_uri;
 
   old_locator_uri = locator->uri;
   locator->uri = xslt_uri;
@@ -1034,9 +1033,11 @@ raptor_grddl_seen_uri(raptor_grddl_parser_context* grddl_parser,
     }
   }
 
+#ifdef RAPTOR_DEBUG
   if(seen)
     RAPTOR_DEBUG2("Already seen URI '%s'\n", raptor_uri_as_string(uri));
-  
+#endif
+
   return seen;
 }
 
@@ -1086,7 +1087,7 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
 
   nodes = xpathObj->nodesetval;
   if(!nodes || xmlXPathNodeSetIsEmpty(nodes)) {
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     RAPTOR_DEBUG3("No match found with XPath expression \"%s\" over '%s'\n",
                   xpathExpr, raptor_uri_as_string(rdf_parser->base_uri));
 #endif
@@ -1094,7 +1095,7 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
     goto cleanup_xpath_match;
   }
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   RAPTOR_DEBUG3("Found match with XPath expression \"%s\" over '%s'\n",
                 xpathExpr, raptor_uri_as_string(rdf_parser->base_uri));
 #endif
@@ -1138,7 +1139,7 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
     if(base_uri_string) {
       base_uri = raptor_new_uri(rdf_parser->world, base_uri_string);
       xmlFree(base_uri_string);
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
       RAPTOR_DEBUG2("XML base URI of match is '%s'\n",
                     raptor_uri_as_string(base_uri));
 #endif
@@ -1153,7 +1154,7 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
       char* buffer;
       size_t list_len = strlen((const char*)uri_string);
       
-      buffer = (char*)RAPTOR_MALLOC(cstring, list_len+1);
+      buffer = RAPTOR_MALLOC(char*, list_len + 1);
       memcpy(buffer, uri_string, list_len + 1);
       
       for(start = end = buffer; end; start = end+1) {
@@ -1166,9 +1167,7 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
         if(start == end)
           continue;
         
-#if RAPTOR_DEBUG
         RAPTOR_DEBUG2("Got list match URI '%s'\n", start);
-#endif
         
         uri = raptor_new_uri_relative_to_base(rdf_parser->world,
                                                base_uri,
@@ -1183,18 +1182,14 @@ raptor_grddl_run_xpath_match(raptor_parser* rdf_parser,
         xml_context = raptor_new_xml_context(rdf_parser->world, uri, base_uri);
         raptor_sequence_push(seq, xml_context);
       }
-      RAPTOR_FREE(cstring, buffer);
+      RAPTOR_FREE(char*, buffer);
     } else if(flags & MATCH_IS_HARDCODED) {
-#if RAPTOR_DEBUG
       RAPTOR_DEBUG2("Got hardcoded XSLT match for %s\n", xpathExpr);
-#endif
       /* return at first match, that's enough */
       break;
     } else {
       grddl_xml_context* xml_context;
-#if RAPTOR_DEBUG
       RAPTOR_DEBUG2("Got single match URI '%s'\n", uri_string);
-#endif
 
       uri = raptor_new_uri_relative_to_base(rdf_parser->world, base_uri,
                                             uri_string);
@@ -1231,8 +1226,8 @@ raptor_grddl_check_recursive_content_type_handler(raptor_www* www,
 
   len = strlen(content_type)+1;
   if(grddl_parser->content_type)
-    RAPTOR_FREE(cstring,grddl_parser->content_type);
-  grddl_parser->content_type = (char*)RAPTOR_MALLOC(cstring, len+1);
+    RAPTOR_FREE(char*, grddl_parser->content_type);
+  grddl_parser->content_type = RAPTOR_MALLOC(char*, len + 1);
   memcpy(grddl_parser->content_type, content_type, len + 1);
 
   if(!strncmp(content_type, "application/rdf+xml", 19)) {
@@ -1330,7 +1325,7 @@ raptor_grddl_run_recursive(raptor_parser* rdf_parser, raptor_uri* uri,
       }      
     }
     
-    RAPTOR_FREE(cstring, ibuffer);
+    RAPTOR_FREE(char*, ibuffer);
     raptor_parser_save_content(grddl_parser->internal_parser, 0);
   }
 
@@ -1368,7 +1363,7 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
   /* XML document DOM */
   xmlDocPtr doc;
   int expri;
-  const unsigned char* buffer = NULL;
+  unsigned char* buffer = NULL;
   size_t buffer_len = 0;
   int buffer_is_libxml = 0;
   int loop;
@@ -1408,10 +1403,10 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
     return 0;
 
   buffer_len = raptor_stringbuffer_length(grddl_parser->sb);
-  buffer = (const unsigned char*)RAPTOR_MALLOC(cstring, buffer_len+1);
+  buffer = RAPTOR_MALLOC(unsigned char*, buffer_len + 1);
   if(buffer)
     raptor_stringbuffer_copy_to_string(grddl_parser->sb, 
-                                       (unsigned char*)buffer, buffer_len);
+                                       buffer, buffer_len);
   
 
   uri_string = raptor_uri_as_string(rdf_parser->base_uri);
@@ -1433,7 +1428,7 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
       /* try to create an XML parser context */
       grddl_parser->xml_ctxt = xmlCreatePushParserCtxt(NULL, NULL,
                                                        (const char*)buffer,
-                                                       buffer_len,
+                                                       RAPTOR_BAD_CAST(int, buffer_len),
                                                        (const char*)uri_string);
       if(!grddl_parser->xml_ctxt) {
         RAPTOR_DEBUG2("Parser %p: Creating an XML parser failed\n", rdf_parser);
@@ -1463,11 +1458,12 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
 
         RAPTOR_DEBUG2("Parser %p: Creating an HTML parser\n", rdf_parser);
 
-        enc = xmlDetectCharEncoding((const unsigned char*)buffer, buffer_len);
+        enc = xmlDetectCharEncoding((const unsigned char*)buffer,
+                                    RAPTOR_BAD_CAST(int, buffer_len));
         grddl_parser->html_ctxt = htmlCreatePushParserCtxt(/*sax*/ NULL, 
                                                            /*user_data*/ NULL,
                                                            (const char *)buffer,
-                                                           buffer_len,
+                                                           RAPTOR_BAD_CAST(int, buffer_len),
                                                            (const char *)uri_string,
                                                            enc);
         if(!grddl_parser->html_ctxt) {
@@ -1572,7 +1568,7 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
       int blen;
       
       /* write the result of XML Include to buffer */
-      RAPTOR_FREE(cstring, buffer);
+      RAPTOR_FREE(char*, buffer);
       xmlDocDumpFormatMemory(doc, (xmlChar**)&buffer, &blen,
                              1 /* indent the result */);
       buffer_len = blen;
@@ -1880,7 +1876,7 @@ raptor_grddl_parse_chunk(raptor_parser* rdf_parser,
     if(buffer_is_libxml)
       xmlFree((xmlChar*)buffer);
     else
-      RAPTOR_FREE(cstring, buffer);
+      RAPTOR_FREE(char*, buffer);
   }
 
   if(grddl_parser->sb) {
@@ -1948,9 +1944,9 @@ raptor_grddl_parse_content_type_handler(raptor_parser* rdf_parser,
   if(content_type) {
     size_t len = strlen(content_type) + 1;
     if(grddl_parser->content_type)
-      RAPTOR_FREE(cstring,grddl_parser->content_type);
+      RAPTOR_FREE(char*, grddl_parser->content_type);
     
-    grddl_parser->content_type = (char*)RAPTOR_MALLOC(cstring, len+1);
+    grddl_parser->content_type = RAPTOR_MALLOC(char*, len + 1);
     memcpy(grddl_parser->content_type, content_type, len + 1);
   }
 }
