@@ -36,6 +36,10 @@ extern "C" {
 
 #ifdef RAPTOR_INTERNAL
 
+#ifdef MAINTAINER_MODE
+#include <git-version.h>
+#endif
+
 /* for the memory allocation functions */
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -58,15 +62,15 @@ void* raptor_sign_calloc(size_t nmemb, size_t size);
 void* raptor_sign_realloc(void *ptr, size_t size);
 void raptor_sign_free(void *ptr);
   
-#define RAPTOR_MALLOC(type, size)   raptor_sign_malloc(size)
-#define RAPTOR_CALLOC(type, nmemb, size) raptor_sign_calloc(nmemb, size)
-#define RAPTOR_REALLOC(type, ptr, size) raptor_sign_realloc(ptr, size)
-#define RAPTOR_FREE(type, ptr)   raptor_sign_free(ptr)
+#define RAPTOR_MALLOC(type, size)   (type)raptor_sign_malloc(size)
+#define RAPTOR_CALLOC(type, nmemb, size) (type)raptor_sign_calloc(nmemb, size)
+#define RAPTOR_REALLOC(type, ptr, size) (type)raptor_sign_realloc(ptr, size)
+#define RAPTOR_FREE(type, ptr)   raptor_sign_free((void*)ptr)
 
 #else
-#define RAPTOR_MALLOC(type, size) malloc(size)
-#define RAPTOR_CALLOC(type, nmemb, size) calloc(nmemb, size)
-#define RAPTOR_REALLOC(type, ptr, size) realloc(ptr, size)
+#define RAPTOR_MALLOC(type, size) (type)malloc(size)
+#define RAPTOR_CALLOC(type, nmemb, size) (type)calloc(nmemb, size)
+#define RAPTOR_REALLOC(type, ptr, size) (type)realloc(ptr, size)
 #define RAPTOR_FREE(type, ptr)   free((void*)ptr)
 
 #endif
@@ -447,7 +451,7 @@ struct raptor_namespace_s {
   /* NULL means is the default namespace */
   const unsigned char *prefix;
   /* needed to safely compare prefixed-names */
-  int prefix_length;
+  unsigned int prefix_length;
   /* URI of namespace or NULL for default */
   raptor_uri *uri;
   /* parsing depth that this ns was added.  It will
@@ -469,6 +473,14 @@ raptor_namespace** raptor_namespace_stack_to_array(raptor_namespace_stack *nstac
 #endif
 
 
+/* Size of buffer to use when reading from a file */
+#ifdef BUFSIZ
+#define RAPTOR_READ_BUFFER_SIZE BUFSIZ
+#else
+#define RAPTOR_READ_BUFFER_SIZE 4096
+#endif
+
+
 /*
  * Raptor parser object
  */
@@ -534,6 +546,9 @@ struct raptor_parser_s {
 
   /* internal data for lexers */
   void* lexer_user_data;
+
+  /* internal read buffer */
+  unsigned char buffer[RAPTOR_READ_BUFFER_SIZE + 1];
 };
 
 
@@ -721,7 +736,7 @@ extern void raptor_xml_characters_handler(void *user_data, const unsigned char *
 extern void raptor_xml_cdata_handler(void *user_data, const unsigned char *s, int len);
 void raptor_xml_comment_handler(void *user_data, const unsigned char *s);
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
 void raptor_rdfxml_parser_stats_print(raptor_rdfxml_parser* rdf_xml_parser, FILE *stream);
 #endif
 
@@ -776,7 +791,7 @@ struct raptor_qname_s {
   raptor_uri *uri;
   /* optional value - used when name is an attribute */
   const unsigned char *value;
-  unsigned int value_length;
+  size_t value_length;
 };
 
 
@@ -920,7 +935,6 @@ int raptor_unicode_check_utf8_nfc_string(const unsigned char *input, size_t leng
 
 #ifdef RAPTOR_WWW_LIBCURL
 #include <curl/curl.h>
-#include <curl/types.h>
 #include <curl/easy.h>
 #endif
 
@@ -934,7 +948,7 @@ struct  raptor_www_s {
   raptor_world* world;
   char *type;
   int free_type;
-  int total_bytes;
+  size_t total_bytes;
   int failed;
   int status_code;
 
@@ -949,14 +963,11 @@ struct  raptor_www_s {
 
 #ifdef RAPTOR_WWW_LIBXML
   void *ctxt;
-  char buffer[RAPTOR_WWW_BUFFER_SIZE];
   int is_end;
   void *old_xmlGenericErrorContext;
 #endif
 
-#ifdef RAPTOR_WWW_LIBFETCH
-  char buffer[RAPTOR_WWW_BUFFER_SIZE];
-#endif
+  char buffer[RAPTOR_WWW_BUFFER_SIZE + 1];
 
   char *user_agent;
 
@@ -1001,6 +1012,7 @@ void raptor_www_error(raptor_www *www, const char *message, ...) RAPTOR_PRINTF_F
 void raptor_www_curl_init(raptor_www *www);
 void raptor_www_curl_free(raptor_www *www);
 int raptor_www_curl_fetch(raptor_www *www);
+int raptor_www_curl_set_ssl_cert_options(raptor_www* www, const char* cert_filename, const char* cert_type, const char* cert_passphrase);
 
 void raptor_www_libfetch_init(raptor_www *www);
 void raptor_www_libfetch_free(raptor_www *www);
@@ -1010,7 +1022,7 @@ int raptor_www_libfetch_fetch(raptor_www *www);
 raptor_id_set* raptor_new_id_set(raptor_world* world);
 void raptor_free_id_set(raptor_id_set* set);
 int raptor_id_set_add(raptor_id_set* set, raptor_uri* base_uri, const unsigned char *item, size_t item_len);
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
 void raptor_id_set_stats_print(raptor_id_set* set, FILE *stream);
 #endif
 
@@ -1282,6 +1294,7 @@ int raptor_turtle_writer_set_option(raptor_turtle_writer *turtle_writer, raptor_
 int raptor_turtle_writer_set_option_string(raptor_turtle_writer *turtle_writer, raptor_option option, const unsigned char *value);
 int raptor_turtle_writer_get_option(raptor_turtle_writer *turtle_writer, raptor_option option);
 const unsigned char *raptor_turtle_writer_get_option_string(raptor_turtle_writer *turtle_writer, raptor_option option);
+void raptor_turtle_writer_bnodeid(raptor_turtle_writer* turtle_writer, const unsigned char *bnodeid, size_t len);
 
 
 /**
@@ -1314,7 +1327,7 @@ int raptor_rdfxmla_serialize_set_single_node(raptor_serializer* serializer, rapt
 int raptor_rdfxmla_serialize_set_write_typed_nodes(raptor_serializer* serializer, int value);
 
 /* snprintf.c */
-char* raptor_format_float(char *buffer, size_t *currlen, size_t maxlen, double fvalue, unsigned int min, unsigned int max, int flags);
+int raptor_format_integer(char* buffer, size_t bufsize, int integer, unsigned int base, int width, char padding);
 
 /* raptor_world structure */
 #define RAPTOR1_WORLD_MAGIC_1 0
@@ -1406,13 +1419,24 @@ struct raptor_world_s {
 
   int default_generate_bnodeid_handler_base;
   char *default_generate_bnodeid_handler_prefix;
-  size_t default_generate_bnodeid_handler_prefix_length;
+  unsigned int default_generate_bnodeid_handler_prefix_length;
 };
 
 /* raptor_www.c */
 int raptor_www_init(raptor_world* world);
 void raptor_www_finish(raptor_world* world);
 
+
+
+#define RAPTOR_LANG_LEN_FROM_INT(len) (int)(len)
+#define RAPTOR_LANG_LEN_TO_SIZE_T(len) (size_t)(len)
+
+/* Safe casts: widening a value */
+#define RAPTOR_GOOD_CAST(t, v) (t)(v)
+
+/* Unsafe casts: narrowing a value */
+#define RAPTOR_BAD_CAST(t, v) (t)(v)
+
 /* end of RAPTOR_INTERNAL */
 #endif
 
