@@ -126,7 +126,7 @@ raptor_new_iostream_from_handler(raptor_world *world,
   if(!raptor_iostream_check_handler(handler, 0))
     return NULL;
 
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr)
     return NULL;
 
@@ -157,7 +157,7 @@ static int
 raptor_sink_iostream_write_bytes(void *user_data, const void *ptr,
                                  size_t size, size_t nmemb)
 {
-  return size*nmemb; /* success */
+  return RAPTOR_BAD_CAST(int, size * nmemb); /* success */
 }
 
 static int
@@ -226,7 +226,7 @@ raptor_filename_iostream_write_bytes(void *user_data,
                                      const void *ptr, size_t size, size_t nmemb)
 {
   FILE* handle = (FILE*)user_data;
-  return (int)fwrite(ptr, size, nmemb, handle);
+  return RAPTOR_BAD_CAST(int, fwrite(ptr, size, nmemb, handle));
 }
 
 static int
@@ -241,7 +241,7 @@ raptor_filename_iostream_read_bytes(void *user_data,
                                     void *ptr, size_t size, size_t nmemb)
 {
   FILE* handle = (FILE*)user_data;
-  return fread(ptr, size, nmemb, handle);
+  return RAPTOR_BAD_CAST(int, fread(ptr, size, nmemb, handle));
 }
 
 static int
@@ -295,7 +295,7 @@ raptor_new_iostream_to_filename(raptor_world *world, const char *filename)
   if(!handle)
     return NULL;
   
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr) {
     fclose(handle);
     return NULL;
@@ -357,7 +357,7 @@ raptor_new_iostream_to_file_handle(raptor_world *world, FILE *handle)
   if(!raptor_iostream_check_handler(handler, mode))
     return NULL;
 
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr)
     return NULL;
 
@@ -437,7 +437,7 @@ raptor_write_string_iostream_write_bytes(void *user_data, const void *ptr,
   if(raptor_stringbuffer_append_counted_string(con->sb,
                                                (const unsigned char*)ptr, size * nmemb, 1))
     return 0; /* failure */
-  return size * nmemb; /* success */
+  return RAPTOR_BAD_CAST(int, size * nmemb); /* success */
 }
 
 static const raptor_iostream_handler raptor_iostream_write_string_handler = {
@@ -489,11 +489,12 @@ raptor_new_iostream_to_string(raptor_world *world,
   if(!raptor_iostream_check_handler(handler, mode))
     return NULL;
 
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr)
     return NULL;
 
-  con = (struct raptor_write_string_iostream_context*)RAPTOR_CALLOC(raptor_write_string_iostream_context, 1, sizeof(*con));
+  con = RAPTOR_CALLOC(struct raptor_write_string_iostream_context*, 1,
+                      sizeof(*con));
   if(!con) {
     RAPTOR_FREE(raptor_iostream, iostr);
     return NULL;
@@ -595,7 +596,7 @@ raptor_new_iostream_from_filename(raptor_world *world, const char *filename)
   if(!handle)
     return NULL;
   
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr) {
     fclose(handle);
     return NULL;
@@ -657,7 +658,7 @@ raptor_new_iostream_from_file_handle(raptor_world *world, FILE *handle)
   if(!raptor_iostream_check_handler(handler, mode))
     return NULL;
 
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr)
     return NULL;
 
@@ -770,7 +771,7 @@ int
 raptor_iostream_string_write(const void *string, raptor_iostream *iostr)
 {
   size_t len = strlen((const char*)string);
-  return (raptor_iostream_write_bytes(string, 1, len, iostr) != (int)len);
+  return (raptor_iostream_write_bytes(string, 1, len, iostr) != RAPTOR_BAD_CAST(int, len));
 }
 
 
@@ -788,7 +789,7 @@ int
 raptor_iostream_counted_string_write(const void *string, size_t len,
                                      raptor_iostream *iostr) 
 {
-  return (raptor_iostream_write_bytes(string, 1, len, iostr) != (int)len);
+  return (raptor_iostream_write_bytes(string, 1, len, iostr) != RAPTOR_BAD_CAST(int, len));
 }
 
 
@@ -806,7 +807,7 @@ raptor_uri_write(raptor_uri* uri, raptor_iostream* iostr)
 {
   size_t len;
   const void *string = raptor_uri_as_counted_string(uri, &len);
-  return (raptor_iostream_write_bytes(string, 1, len, iostr) != (int)len);
+  return (raptor_iostream_write_bytes(string, 1, len, iostr) != RAPTOR_BAD_CAST(int, len));
 }
 
 
@@ -845,15 +846,15 @@ raptor_iostream_write_end(raptor_iostream *iostr)
 int
 raptor_stringbuffer_write(raptor_stringbuffer *sb, raptor_iostream* iostr)
 {
-  int length;
+  size_t length;
   if(!sb)
     return 1;
   
-  length = (int)raptor_stringbuffer_length(sb);
+  length = raptor_stringbuffer_length(sb);
   if(length) {
     int count = raptor_iostream_write_bytes(raptor_stringbuffer_as_string(sb),
                                             1, length, iostr);
-    return (count != length);
+    return (RAPTOR_BAD_CAST(size_t, count) != length);
   } else
     return 0;
 }
@@ -916,28 +917,21 @@ int
 raptor_iostream_hexadecimal_write(unsigned int integer, int width,
                                   raptor_iostream* iostr)
 {
-  unsigned char *buf;
-  unsigned char *p;
+  char *buf;
   int rc;
 
-  if(width <1)
+  if(width < 1)
     return 1;
   
-  buf = (unsigned char*)RAPTOR_MALLOC(cstring, width);
+  buf = RAPTOR_MALLOC(char*, width + 1);
   if(!buf)
     return 1;
   
-  p = buf+width-1;
-  do {
-    unsigned int digit = (integer & 15);
-    *p-- =(digit < 10) ? '0'+digit : 'A'+(digit-10);
-    integer >>= 4;
-  } while(integer);
-  while(p >= buf)
-    *p-- = '0';
-  
+  (void)raptor_format_integer(buf, width + 1, integer, /* base */ 16,
+                              width, '0');
+
   rc = raptor_iostream_write_bytes(buf, 1, width, iostr);
-  RAPTOR_FREE(cstring, buf);
+  RAPTOR_FREE(char*, buf);
   return rc;
 }
 
@@ -974,7 +968,7 @@ raptor_iostream_read_bytes(void *ptr, size_t size, size_t nmemb,
   if(count > 0)
     iostr->offset += (size*count);
 
-  if(count < (int)nmemb)
+  if(RAPTOR_BAD_CAST(size_t, count) < nmemb)
     iostr->flags |= RAPTOR_IOSTREAM_FLAGS_EOF;
   
   return count;
@@ -1041,14 +1035,14 @@ raptor_read_string_iostream_read_bytes(void *user_data, void *ptr,
   if(con->offset >= con->length)
     return 0;
 
-  avail = (int)((con->length-con->offset) / size);  
+  avail = (con->length - con->offset) / size;
   if(avail > nmemb)
     avail = nmemb;
   blen = (avail * size);
   memcpy(ptr, (char*)con->string + con->offset, blen);
-  con->offset+= blen;
+  con->offset += blen;
   
-  return avail;
+  return RAPTOR_BAD_CAST(int, avail);
 }
 
 static int
@@ -1103,11 +1097,12 @@ raptor_new_iostream_from_string(raptor_world *world,
   if(!raptor_iostream_check_handler(handler, mode))
     return NULL;
 
-  iostr = (raptor_iostream*)RAPTOR_CALLOC(raptor_iostream, 1, sizeof(*iostr));
+  iostr = RAPTOR_CALLOC(raptor_iostream*, 1, sizeof(*iostr));
   if(!iostr)
     return NULL;
 
-  con = (struct raptor_read_string_iostream_context*)RAPTOR_CALLOC(raptor_read_string_iostream_context, 1, sizeof(*con));
+  con = RAPTOR_CALLOC(struct raptor_read_string_iostream_context*, 1,
+                      sizeof(*con));
   if(!con) {
     RAPTOR_FREE(raptor_iostream, iostr);
     return NULL;
@@ -1177,7 +1172,7 @@ test_write_to_filename(raptor_world *world, const char* filename,
   int rc = 0;
   const char* const label="write iostream to filename";
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s '%s'\n", program, label, filename);
 #endif
 
@@ -1221,7 +1216,7 @@ test_write_to_file_handle(raptor_world *world, FILE* handle,
   int rc = 0;
   const char* const label="write iostream to file handle";
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s\n", program, label);
 #endif
 
@@ -1266,7 +1261,7 @@ test_write_to_string(raptor_world *world,
   const char* const label="write iostream to a string";
 
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s\n", program, label);
 #endif
 
@@ -1323,7 +1318,7 @@ test_write_to_sink(raptor_world *world,
   int rc = 0;
   const char* const label="write iostream to sink";
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s\n", program, label);
 #endif
 
@@ -1368,7 +1363,7 @@ test_read_from_filename(raptor_world *world,
   int rc = 0;
   const char* const label="read iostream from filename";
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s '%s'\n", program, label, filename);
 #endif
 
@@ -1430,7 +1425,7 @@ test_read_from_file_handle(raptor_world *world, FILE* handle,
   int rc = 0;
   const char* const label="read iostream from file handle";
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s\n", program, label);
 #endif
 
@@ -1489,7 +1484,7 @@ test_read_from_string(raptor_world *world,
   int rc = 0;
   const char* const label="read iostream from a string";
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s\n", program, label);
 #endif
   
@@ -1539,7 +1534,7 @@ test_read_from_sink(raptor_world *world, size_t read_len, size_t expected_len)
   int rc = 0;
   const char* const label="read iostream from sink";
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Testing %s\n", program, label);
 #endif
   expected_len = 0;
