@@ -172,8 +172,7 @@ raptor_world_register_parser_factory(raptor_world* world,
 {
   raptor_parser_factory *parser = NULL;
   
-  parser = (raptor_parser_factory*)RAPTOR_CALLOC(raptor_parser_factory, 1,
-                                                 sizeof(*parser));
+  parser = RAPTOR_CALLOC(raptor_parser_factory*, 1, sizeof(*parser));
   if(!parser)
     return NULL;
 
@@ -327,16 +326,14 @@ raptor_new_parser(raptor_world* world, const char *name)
   if(!factory)
     return NULL;
 
-  rdf_parser = (raptor_parser*)RAPTOR_CALLOC(raptor_parser, 1,
-                                             sizeof(*rdf_parser));
+  rdf_parser = RAPTOR_CALLOC(raptor_parser*, 1, sizeof(*rdf_parser));
   if(!rdf_parser)
     return NULL;
 
   rdf_parser->world = world;
   raptor_statement_init(&rdf_parser->statement, world);
   
-  rdf_parser->context = (char*)RAPTOR_CALLOC(raptor_parser_context, 1,
-                                             factory->context_length);
+  rdf_parser->context = RAPTOR_CALLOC(void*, 1, factory->context_length);
   if(!rdf_parser->context) {
     raptor_free_parser(rdf_parser);
     return NULL;
@@ -505,10 +502,6 @@ raptor_free_parser(raptor_parser* rdf_parser)
 }
 
 
-/* Size of XML buffer to use when reading from a file */
-#define RAPTOR_READ_BUFFER_SIZE 4096
-
-
 /**
  * raptor_parser_parse_file_stream:
  * @rdf_parser: parser
@@ -527,10 +520,8 @@ raptor_parser_parse_file_stream(raptor_parser* rdf_parser,
                                 FILE *stream, const char* filename,
                                 raptor_uri *base_uri)
 {
-  /* Read buffer */
-  unsigned char buffer[RAPTOR_READ_BUFFER_SIZE+1];
   int rc = 0;
-  raptor_locator *locator=&rdf_parser->locator;
+  raptor_locator *locator = &rdf_parser->locator;
 
   if(!stream || !base_uri)
     return 1;
@@ -542,10 +533,10 @@ raptor_parser_parse_file_stream(raptor_parser* rdf_parser,
     return 1;
   
   while(!feof(stream)) {
-    int len = fread(buffer, 1, RAPTOR_READ_BUFFER_SIZE, stream);
+    size_t len = fread(rdf_parser->buffer, 1, RAPTOR_READ_BUFFER_SIZE, stream);
     int is_end = (len < RAPTOR_READ_BUFFER_SIZE);
-    buffer[len] = '\0';
-    rc = raptor_parser_parse_chunk(rdf_parser, buffer, len, is_end);
+    rdf_parser->buffer[len] = '\0';
+    rc = raptor_parser_parse_chunk(rdf_parser, rdf_parser->buffer, len, is_end);
     if(rc || is_end)
       break;
   }
@@ -613,7 +604,7 @@ raptor_parser_parse_file(raptor_parser* rdf_parser, raptor_uri *uri,
   if(uri) {
     if(fh)
       fclose(fh);
-    RAPTOR_FREE(cstring, (void*)filename);
+    RAPTOR_FREE(char*, filename);
   }
   if(free_base_uri)
     raptor_free_uri(base_uri);
@@ -628,7 +619,7 @@ raptor_parser_parse_uri_write_bytes(raptor_www* www,
                                     size_t size, size_t nmemb)
 {
   raptor_parse_bytes_context* rpbc = (raptor_parse_bytes_context*)userdata;
-  int len = size*nmemb;
+  size_t len = size * nmemb;
 
   if(!rpbc->started) {
     raptor_uri* base_uri = rpbc->base_uri;
@@ -728,6 +719,9 @@ raptor_parser_parse_uri_with_connection(raptor_parser* rdf_parser,
   int ret = 0;
   raptor_parse_bytes_context rpbc;
   char* ua = NULL;
+  char* cert_filename = NULL;
+  char* cert_type = NULL;
+  char* cert_passphrase = NULL;
   
   if(connection) {
     if(rdf_parser->www)
@@ -748,7 +742,7 @@ raptor_parser_parse_uri_with_connection(raptor_parser* rdf_parser,
     accept_h = raptor_parser_get_accept_header(rdf_parser);
     if(accept_h) {
       raptor_www_set_http_accept(rdf_parser->www, accept_h);
-      RAPTOR_FREE(cstring, accept_h);
+      RAPTOR_FREE(char*, accept_h);
     }
   }
 
@@ -779,6 +773,16 @@ raptor_parser_parse_uri_with_connection(raptor_parser* rdf_parser,
   ua = RAPTOR_OPTIONS_GET_STRING(rdf_parser, RAPTOR_OPTION_WWW_HTTP_USER_AGENT);
   if(ua)
     raptor_www_set_user_agent(rdf_parser->www, ua);
+
+  cert_filename = RAPTOR_OPTIONS_GET_STRING(rdf_parser,
+                                            RAPTOR_OPTION_WWW_CERT_FILENAME);
+  cert_type = RAPTOR_OPTIONS_GET_STRING(rdf_parser,
+                                        RAPTOR_OPTION_WWW_CERT_TYPE);
+  cert_passphrase = RAPTOR_OPTIONS_GET_STRING(rdf_parser,
+                                              RAPTOR_OPTION_WWW_CERT_PASSPHRASE);
+  if(cert_filename || cert_type || cert_passphrase)
+    raptor_www_set_ssl_cert_options(rdf_parser->www, cert_filename,
+                                    cert_type, cert_passphrase);
   
   ret = raptor_www_fetch(rdf_parser->www, uri);
   
@@ -1166,7 +1170,7 @@ void
 raptor_stats_print(raptor_parser *rdf_parser, FILE *stream)
 {
 #ifdef RAPTOR_PARSER_RDFXML
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   if(!strcmp(rdf_parser->factory->desc.names[0], "rdfxml")) {
     raptor_rdfxml_parser *rdf_xml_parser = (raptor_rdfxml_parser*)rdf_parser->context;
     fputs("raptor parser stats\n  ", stream);
@@ -1223,9 +1227,9 @@ raptor_world_guess_parser_name(raptor_world* world,
 
   raptor_world_open(world);
 
-  scores = (struct syntax_score*)RAPTOR_CALLOC(syntax_scores,
-                                               raptor_sequence_size(world->parsers),
-                                               sizeof(struct syntax_score));
+  scores = RAPTOR_CALLOC(struct syntax_score*,
+                         raptor_sequence_size(world->parsers),
+                         sizeof(struct syntax_score));
   if(!scores)
     return NULL;
   
@@ -1235,8 +1239,7 @@ raptor_world_guess_parser_name(raptor_world* world,
       unsigned char *from, *to;
 
       p++;
-      suffix = (unsigned char*)RAPTOR_MALLOC(cstring,
-                                             strlen((const char*)p) + 1);
+      suffix = RAPTOR_MALLOC(unsigned char*, strlen((const char*)p) + 1);
       if(!suffix)
         return NULL;
 
@@ -1244,7 +1247,7 @@ raptor_world_guess_parser_name(raptor_world* world,
         unsigned char c = *from++;
         /* discard the suffix if it wasn't '\.[a-zA-Z0-9]+$' */
         if(!isalpha(c) && !isdigit(c)) {
-          RAPTOR_FREE(cstring, suffix);
+          RAPTOR_FREE(char*, suffix);
           suffix = NULL;
           to = NULL;
           break;
@@ -1317,7 +1320,7 @@ raptor_world_guess_parser_name(raptor_world* world,
 
     scores[i].score = score < 10 ? score : 10; 
     scores[i].factory = factory;
-#if RAPTOR_DEBUG > 2
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 2
     RAPTOR_DEBUG3("Score %15s : %d\n", factory->desc.names[0], score);
 #endif
   }
@@ -1330,7 +1333,7 @@ raptor_world_guess_parser_name(raptor_world* world,
   }
 
   if(suffix)
-    RAPTOR_FREE(cstring, suffix);
+    RAPTOR_FREE(char*, suffix);
 
   RAPTOR_FREE(syntax_scores, scores);
   
@@ -1447,7 +1450,7 @@ raptor_parser_get_accept_header(raptor_parser* rdf_parser)
   
   /* 9 = strlen("\*\/\*;q=0.1") */
 #define ACCEPT_HEADER_LEN 9
-  accept_header = (char*)RAPTOR_MALLOC(cstring, len + ACCEPT_HEADER_LEN + 1);
+  accept_header = RAPTOR_MALLOC(char*, len + ACCEPT_HEADER_LEN + 1);
   if(!accept_header)
     return NULL;
 
@@ -1503,7 +1506,7 @@ raptor_parser_get_accept_header_all(raptor_world* world)
   
   /* 9 = strlen("\*\/\*;q=0.1") */
 #define ACCEPT_HEADER_LEN 9
-  accept_header = (char*)RAPTOR_MALLOC(cstring, len + ACCEPT_HEADER_LEN + 1);
+  accept_header = RAPTOR_MALLOC(char*, len + ACCEPT_HEADER_LEN + 1);
   if(!accept_header)
     return NULL;
 
@@ -1560,7 +1563,7 @@ raptor_parser_get_content(raptor_parser* rdf_parser, size_t* length_p)
     return NULL;
   
   len = raptor_stringbuffer_length(rdf_parser->sb);
-  buffer = (unsigned char*)RAPTOR_MALLOC(cstring, len+1);
+  buffer = RAPTOR_MALLOC(unsigned char*, len + 1);
   if(!buffer)
     return NULL;
 
@@ -1656,8 +1659,6 @@ int
 raptor_parser_parse_iostream(raptor_parser* rdf_parser, raptor_iostream *iostr,
                              raptor_uri *base_uri)
 {
-  /* Read buffer */
-  unsigned char buffer[RAPTOR_READ_BUFFER_SIZE + 1];
   int rc = 0;
 
   RAPTOR_ASSERT_OBJECT_POINTER_RETURN_VALUE(rdf_parser, raptor_parser, 1);
@@ -1668,11 +1669,11 @@ raptor_parser_parse_iostream(raptor_parser* rdf_parser, raptor_iostream *iostr,
     return rc;
   
   while(!raptor_iostream_read_eof(iostr)) {
-    int len = raptor_iostream_read_bytes(buffer, 1, RAPTOR_READ_BUFFER_SIZE,
-                                         iostr);
+    size_t len = raptor_iostream_read_bytes(rdf_parser->buffer, 1,
+                                            RAPTOR_READ_BUFFER_SIZE, iostr);
     int is_end = (len < RAPTOR_READ_BUFFER_SIZE);
 
-    rc = raptor_parser_parse_chunk(rdf_parser, buffer, len, is_end);
+    rc = raptor_parser_parse_chunk(rdf_parser, rdf_parser->buffer, len, is_end);
     if(rc || is_end)
       break;
   }
@@ -1703,7 +1704,7 @@ main(int argc, char *argv[])
   if(!world || raptor_world_open(world))
     exit(1);
   
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Known options:\n", program);
 #endif
 
@@ -1717,7 +1718,7 @@ main(int argc, char *argv[])
     if(!od)
       continue;
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     fprintf(stderr, " %2d %-20s %s <%s>\n", i, od->name, od->label,
             (od->uri ? (const char*)raptor_uri_as_string(od->uri) : ""));
 #endif
@@ -1732,7 +1733,7 @@ main(int argc, char *argv[])
   }
 
   s = raptor_parser_get_accept_header_all(world);
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "Default HTTP accept header: '%s'\n", s);
 #endif
   if(!s) {
@@ -1740,7 +1741,7 @@ main(int argc, char *argv[])
             program);
     return 1;
   }
-  RAPTOR_FREE(cstring, s);
+  RAPTOR_FREE(char*, s);
 
   raptor_free_world(world);
   
