@@ -40,7 +40,7 @@
 
 
 /* Raptor includes */
-#include "raptor.h"
+#include "raptor2.h"
 #include "raptor_internal.h"
 #include "raptor_rss.h"
 
@@ -364,7 +364,7 @@ raptor_rss_block_set_field(raptor_world *world, raptor_uri *base_uri,
     block->urls[offset] = uri;
   } else if(attribute_type == RSS_BLOCK_FIELD_TYPE_STRING) {
     size_t len = strlen(string);
-    block->strings[offset] = (char*)RAPTOR_MALLOC(cstring, len+1);
+    block->strings[offset] = RAPTOR_MALLOC(char*, len + 1);
     if(!block->strings[offset])
       return 1;
 
@@ -399,8 +399,7 @@ raptor_rss_start_element_handler(void *user_data,
   rdf_parser = (raptor_parser*)user_data;
   rss_parser = (raptor_rss_parser*)rdf_parser->context;
 
-  rss_element = (raptor_rss_element*)RAPTOR_CALLOC(raptor_rss_element, 1,
-                                                   sizeof(*rss_element));
+  rss_element = RAPTOR_CALLOC(raptor_rss_element*, 1, sizeof(*rss_element));
   if(!rss_element) {
     rdf_parser->failed = 1;
     return;
@@ -539,7 +538,7 @@ raptor_rss_start_element_handler(void *user_data,
 
     id = raptor_world_generate_bnodeid(rdf_parser->world);
     block_term = raptor_new_term_from_blank(rdf_parser->world, id);
-    RAPTOR_FREE(cstring, id);
+    RAPTOR_FREE(char*, id);
 
     block = raptor_new_rss_block(rdf_parser->world, block_type, block_term);
     raptor_free_term(block_term);
@@ -556,7 +555,6 @@ raptor_rss_start_element_handler(void *user_data,
         const char* attrName = (const char*)attr->local_name;
         const unsigned char* attrValue = attr->value;
         const raptor_rss_block_field_info *bfi;
-        int attribute_type = -1;
         int offset = -1;
         
         for(bfi = &raptor_rss_block_fields_info[0];
@@ -566,7 +564,6 @@ raptor_rss_start_element_handler(void *user_data,
             continue;
           
           if(bfi->type == block_type && !strcmp(attrName, bfi->attribute)) {
-            attribute_type = bfi->attribute_type;
             offset = bfi->offset;
             break;
           }
@@ -630,7 +627,7 @@ raptor_rss_start_element_handler(void *user_data,
             } else {
               size_t len = strlen((const char*)attrValue);
               RAPTOR_DEBUG2("    setting guid to string '%s'\n", attrValue);
-              field->value = (unsigned char*)RAPTOR_MALLOC(cstring, len+1);
+              field->value = RAPTOR_MALLOC(unsigned char*, len + 1);
               if(!field->value) {
                 rdf_parser->failed = 1;
                 return;
@@ -770,7 +767,7 @@ raptor_rss_end_element_handler(void *user_data,
        (rss_parser->current_field == RAPTOR_RSS_FIELD_NONE ||
         rss_parser->current_field == RAPTOR_RSS_FIELD_UNKNOWN)) {
       unsigned char *p = cdata;
-      int i;
+      size_t i;
       for(i = cdata_len; i > 0 && *p; i--) {
         if(!isspace(*p))
           break;
@@ -800,7 +797,7 @@ raptor_rss_end_element_handler(void *user_data,
       } else {
         RAPTOR_DEBUG4("Added text '%s' to field %s of type %s\n", cdata, raptor_rss_fields_info[rss_parser->current_field].name, raptor_rss_items_info[rss_parser->current_type].name);
         field->uri = NULL;
-        field->value = (unsigned char*)RAPTOR_MALLOC(cstring, cdata_len+1);
+        field->value = RAPTOR_MALLOC(unsigned char*, cdata_len + 1);
         if(!field->value) {
           rdf_parser->failed = 1;
           return;
@@ -955,7 +952,7 @@ raptor_rss_insert_rss_link(raptor_parser* rdf_parser,
     if(!field)
       return 1;
     
-    field->value = (unsigned char*)RAPTOR_MALLOC(cstring, len + 1);
+    field->value = RAPTOR_MALLOC(unsigned char*, len + 1);
     if(!field->value)
       return 1;
     
@@ -1024,15 +1021,21 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
           raptor_rss_field* field;
 
           for(field = item->fields[url_fields[f]]; field; field = field->next) {
-            raptor_uri *new_uri;
+            raptor_uri *new_uri = NULL;
             if(field->value)
               new_uri = raptor_new_uri(rdf_parser->world,
                                        (const unsigned char*)field->value);
             else if(field->uri)
               new_uri = raptor_uri_copy(field->uri);
 
+            if(!new_uri)
+              return 1;
+            
             item->term = raptor_new_term_from_uri(rdf_parser->world, new_uri);
             raptor_free_uri(new_uri);
+            if(!item->term)
+              return 1;
+
             break;
           }
         }
@@ -1043,7 +1046,7 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
           /* need to make bnode */
           id = raptor_world_generate_bnodeid(rdf_parser->world);
           item->term = raptor_new_term_from_blank(rdf_parser->world, id);
-          RAPTOR_FREE(cstring, id);
+          RAPTOR_FREE(char*, id);
         }
       }
 
@@ -1096,7 +1099,7 @@ raptor_rss_insert_identifiers(raptor_parser* rdf_parser)
         /* need to make bnode */
         id = raptor_world_generate_bnodeid(rdf_parser->world);
         item->term = raptor_new_term_from_blank(rdf_parser->world, id);
-        RAPTOR_FREE(cstring, id);
+        RAPTOR_FREE(char*, id);
       }
     }
     
@@ -1409,7 +1412,7 @@ raptor_rss_emit(raptor_parser* rdf_parser)
     
     /* make a new genid for the <rdf:Seq> node */
     items = raptor_new_term_from_blank(rdf_parser->world, id);
-    RAPTOR_FREE(cstring, id);
+    RAPTOR_FREE(char*, id);
 
     /* _:genid1 rdf:type rdf:Seq . */
     if(raptor_rss_emit_type_triple(rdf_parser, items,
@@ -1488,7 +1491,7 @@ raptor_rss_copy_field(raptor_rss_parser* rss_parser,
       /* Otherwise default action is to copy from_field value */
       len = strlen((const char*)item->fields[from_field]->value);
 
-      field->value = (unsigned char*)RAPTOR_MALLOC(cstring, len + 1);
+      field->value = RAPTOR_MALLOC(unsigned char*, len + 1);
       if(!field->value)
         return 1;
       
