@@ -295,8 +295,7 @@ raptor_rdfxml_ensure_writen_header(raptor_serializer* serializer,
      RAPTOR_OPTIONS_GET_NUMERIC(serializer, RAPTOR_OPTION_WRITE_BASE_URI)) {
     const unsigned char* base_uri_string;
 
-    attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 1,
-                                           sizeof(raptor_qname*));
+    attrs = RAPTOR_CALLOC(raptor_qname **, 1, sizeof(raptor_qname*));
     if(!attrs)
       goto tidy;
 
@@ -426,7 +425,7 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
   if(!rdf_Description_element)
     goto oom;
 
-  attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 3, sizeof(raptor_qname*));
+  attrs = RAPTOR_CALLOC(raptor_qname**, 3, sizeof(raptor_qname*));
   if(!attrs)
     goto oom;
   attrs_count = 0;
@@ -456,13 +455,13 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
       attrs[attrs_count] = raptor_new_qname_from_namespace_local_name(serializer->world, context->rdf_nspace, (const unsigned char*)"about",  subject_uri_string);
       if(!attrs[attrs_count]) {
         if(allocated)
-          RAPTOR_FREE(cstring, subject_uri_string);
+          RAPTOR_FREE(char*, subject_uri_string);
         goto oom;
       }
       attrs_count++;
 
       if(allocated)
-        RAPTOR_FREE(cstring, subject_uri_string);
+        RAPTOR_FREE(char*, subject_uri_string);
 
       break;
 
@@ -493,7 +492,7 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
     goto oom;
 
   /* object */
-  attrs = (raptor_qname **)RAPTOR_CALLOC(qnamearray, 3, sizeof(raptor_qname*));
+  attrs = RAPTOR_CALLOC(raptor_qname**, 3, sizeof(raptor_qname*));
   if(!attrs)
     goto oom;
   attrs_count = 0;
@@ -533,7 +532,7 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
         if(len)
           raptor_xml_writer_raw_counted(xml_writer,
                                         (const unsigned char*)statement->object->value.literal.string,
-                                        len);
+                                        RAPTOR_BAD_CAST(unsigned int, len));
       } else {
         if(statement->object->value.literal.datatype) {
           attrs[attrs_count] = raptor_new_qname_from_namespace_local_name(serializer->world, context->rdf_nspace, (const unsigned char*)"datatype", raptor_uri_as_string(statement->object->value.literal.datatype));
@@ -550,7 +549,8 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
 
         if(len)
           raptor_xml_writer_cdata_counted(xml_writer,
-                                          statement->object->value.literal.string, len);
+                                          statement->object->value.literal.string,
+                                          RAPTOR_BAD_CAST(unsigned int, len));
       }
 
       raptor_xml_writer_end_element(xml_writer, predicate_element);
@@ -592,13 +592,13 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
       attrs[attrs_count] = raptor_new_qname_from_namespace_local_name(serializer->world, context->rdf_nspace, (const unsigned char*)"resource", object_uri_string);
       if(!attrs[attrs_count]) {
         if(allocated)
-          RAPTOR_FREE(cstring, object_uri_string);
+          RAPTOR_FREE(char*, object_uri_string);
         goto oom;
       }
       attrs_count++;
 
       if(allocated)
-        RAPTOR_FREE(cstring, object_uri_string);
+        RAPTOR_FREE(char*, object_uri_string);
 
       raptor_xml_element_set_attributes(predicate_element, attrs, attrs_count);
       attrs = NULL; /* attrs ownership transferred to element */
@@ -650,7 +650,7 @@ raptor_rdfxml_serialize_statement(raptor_serializer* serializer,
     raptor_free_namespace(predicate_ns);
 
   if(uri_string)
-    RAPTOR_FREE(cstring, uri_string);
+    RAPTOR_FREE(char*, uri_string);
 
   return rc;
 }
@@ -697,7 +697,8 @@ raptor_rdfxml_serialize_finish_factory(raptor_serializer_factory* factory)
 
 static const char* const rdfxml_names[2] = { "rdfxml", NULL};
 
-static const char* const rdfxml_uri_strings[2] = {
+static const char* const rdfxml_uri_strings[3] = {
+  "http://www.w3.org/ns/formats/RDF_XML",
   "http://www.w3.org/TR/rdf-syntax-grammar",
   NULL
 };
