@@ -127,7 +127,8 @@ raptor_turtle_writer_newline(raptor_turtle_writer *turtle_writer)
 
   while(num_spaces > 0) {
     int count;
-    count = (num_spaces > (int)SPACES_BUFFER_SIZE) ? (int)SPACES_BUFFER_SIZE : num_spaces;
+    count = (num_spaces > RAPTOR_GOOD_CAST(int, SPACES_BUFFER_SIZE)) ? 
+            RAPTOR_GOOD_CAST(int, SPACES_BUFFER_SIZE) : num_spaces;
 
     raptor_iostream_counted_string_write(spaces_buffer, count, turtle_writer->iostr);
 
@@ -165,8 +166,8 @@ raptor_new_turtle_writer(raptor_world* world,
   
   raptor_world_open(world);
 
-  turtle_writer = (raptor_turtle_writer*)RAPTOR_CALLOC(raptor_turtle_writer, 1,
-                                                       sizeof(*turtle_writer));
+  turtle_writer = RAPTOR_CALLOC(raptor_turtle_writer*, 1,
+                                sizeof(*turtle_writer));
 
   if(!turtle_writer)
     return NULL;
@@ -340,7 +341,7 @@ raptor_turtle_writer_reference(raptor_turtle_writer* turtle_writer,
     raptor_string_ntriples_write(uri_str, length, '>', turtle_writer->iostr);
   raptor_iostream_write_byte('>', turtle_writer->iostr);
 
-  RAPTOR_FREE(cstring, uri_str);
+  RAPTOR_FREE(char*, uri_str);
 }
 
 
@@ -449,7 +450,7 @@ raptor_string_python_write(const unsigned char *string,
     /* It is unicode */
     
     unichar_len = raptor_unicode_utf8_string_get_char(string, len, NULL);
-    if(unichar_len < 0 || unichar_len > (int)len)
+    if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > len)
       /* UTF-8 encoding had an error or ended in the middle of a string */
       return 1;
 
@@ -458,13 +459,15 @@ raptor_string_python_write(const unsigned char *string,
       raptor_iostream_counted_string_write(string, unichar_len, iostr);
     } else {
       unichar_len = raptor_unicode_utf8_string_get_char(string, len, &unichar);
+      if(unichar_len < 0)
+        return 1;
 
       if(unichar < 0x10000) {
         raptor_iostream_counted_string_write("\\u", 2, iostr);
-        raptor_iostream_hexadecimal_write(unichar, 4, iostr);
+        raptor_iostream_hexadecimal_write(RAPTOR_GOOD_CAST(unsigned int, unichar), 4, iostr);
       } else {
         raptor_iostream_counted_string_write("\\U", 2, iostr);
-        raptor_iostream_hexadecimal_write(unichar, 8, iostr);
+        raptor_iostream_hexadecimal_write(RAPTOR_GOOD_CAST(unsigned int, unichar), 8, iostr);
       }
     }
     
@@ -726,6 +729,9 @@ raptor_turtle_writer_set_option(raptor_turtle_writer *turtle_writer,
     /* WWW option */
     case RAPTOR_OPTION_WWW_HTTP_CACHE_CONTROL:
     case RAPTOR_OPTION_WWW_HTTP_USER_AGENT:
+    case RAPTOR_OPTION_WWW_CERT_FILENAME:
+    case RAPTOR_OPTION_WWW_CERT_TYPE:
+    case RAPTOR_OPTION_WWW_CERT_PASSPHRASE:
       
     default:
       return -1;
@@ -844,6 +850,9 @@ raptor_turtle_writer_get_option(raptor_turtle_writer *turtle_writer,
     /* WWW option */
     case RAPTOR_OPTION_WWW_HTTP_CACHE_CONTROL:
     case RAPTOR_OPTION_WWW_HTTP_USER_AGENT:
+    case RAPTOR_OPTION_WWW_CERT_FILENAME:
+    case RAPTOR_OPTION_WWW_CERT_TYPE:
+    case RAPTOR_OPTION_WWW_CERT_PASSPHRASE:
       
     default:
       break;
@@ -871,6 +880,25 @@ raptor_turtle_writer_get_option_string(raptor_turtle_writer *turtle_writer,
   return NULL;
 }
 
+
+/**
+ * raptor_turtle_writer_bnodeid:
+ * @turtle_writer: Turtle writer object
+ * @bnodeid: blank node ID to write
+ * @len: length of @bnodeid
+ *
+ * Write a blank node ID with leading _: to the Turtle writer.
+ *
+ **/
+void
+raptor_turtle_writer_bnodeid(raptor_turtle_writer* turtle_writer,
+                             const unsigned char *bnodeid, size_t len)
+{
+  raptor_bnodeid_ntriples_write(bnodeid, len,
+                                turtle_writer->iostr);
+}
+
+
 #endif
 
 
@@ -984,7 +1012,7 @@ main(int argc, char *argv[])
   
   count = raptor_iostream_tell(iostr);
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Freeing iostream\n", program);
 #endif
   raptor_free_iostream(iostr);
@@ -1008,7 +1036,7 @@ main(int argc, char *argv[])
     return 1;
   }
 
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
   fprintf(stderr, "%s: Made Turtle string of %d bytes\n", program, (int)string_len);
   fputs("[[", stderr);
   (void)fwrite(string, 1, string_len, stderr);
