@@ -32,6 +32,7 @@
 #endif
 
 #include <stdio.h>
+#include <string.h>
 #include <stdarg.h>
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
@@ -93,7 +94,7 @@ raptor_unicode_utf8_string_put_char(raptor_unichar c,
 
   /* when no buffer given, return size */
   if(!output)
-    return size;
+    return RAPTOR_GOOD_CAST(int, size); /* ok since size is in range 1..6 */
 
   if(size > length)
     return -1;
@@ -133,7 +134,7 @@ raptor_unicode_utf8_string_put_char(raptor_unichar c,
       output[0] = (unsigned char)c;
   }
 
-  return size;
+  return RAPTOR_GOOD_CAST(int, size); /* ok since size is in range 1..6 */
 }
 
 
@@ -185,7 +186,7 @@ raptor_unicode_utf8_string_get_char(const unsigned char *input, size_t length,
 
 
   if(!output)
-    return size;
+    return RAPTOR_GOOD_CAST(int, size); /* ok since size is in range 1..6 */
 
   if(length < size)
     return -1;
@@ -253,7 +254,7 @@ raptor_unicode_utf8_string_get_char(const unsigned char *input, size_t length,
   if(c > raptor_unicode_max_codepoint)
     return -4;
 
-  return size;
+  return RAPTOR_GOOD_CAST(int, size); /* ok since size is in range 1..6 */
 }
 
 
@@ -833,7 +834,7 @@ raptor_unicode_check_utf8_string(const unsigned char *string, size_t length)
 
     int unichar_len;
     unichar_len = raptor_unicode_utf8_string_get_char(string, length, &unichar);
-    if(unichar_len < 0 || unichar_len > (int)length)
+    if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > length)
       return 0;
 
     if(unichar > raptor_unicode_max_codepoint)
@@ -844,3 +845,100 @@ raptor_unicode_check_utf8_string(const unsigned char *string, size_t length)
   }
   return 1;
 }
+
+
+/**
+ * raptor_unicode_utf8_strlen:
+ * @string: buffer
+ * @length: buffer length
+ *
+ * Calculate the number of Unicode characters in the given UTF-8 encoded buffer
+ *
+ * Return value: number of characters or <0 if sequence is invalid
+ */
+int
+raptor_unicode_utf8_strlen(const unsigned char *string, size_t length)
+{
+  int unicode_length = 0;
+  
+  while(length > 0) {
+    int unichar_len;
+    unichar_len = raptor_unicode_utf8_string_get_char(string, length, NULL);
+    if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > length) {
+      unicode_length = -1;
+      break;
+    }
+    
+    string += unichar_len;
+    length -= unichar_len;
+
+    unicode_length++;
+  }
+
+  return unicode_length;
+}
+
+
+/**
+ * raptor_unicode_utf8_substr:
+ * @dest: destination string buffer to write to (or NULL)
+ * @dest_length_p: location to store actual destination length (or NULL)
+ * @src: source string
+ * @src_length: source length in bytes
+ * @startingLoc: starting location offset 0 for first Unicode character
+ * @length: number of Unicode characters to copy at offset @startingLoc (or < 0)
+ *
+ * Get a unicode (UTF-8) substring of an existing UTF-8 string
+ *
+ * If @dest is NULL, returns the number of bytes needed to write and
+ * does no work.
+ * 
+ * Return value: number of bytes used in destination string or 0 on failure
+ */
+size_t
+raptor_unicode_utf8_substr(unsigned char* dest, size_t* dest_length_p,
+                           const unsigned char* src, size_t src_length,
+                           int startingLoc, int length)
+{
+  size_t dest_length = 0; /* destination unicode characters count */
+  size_t dest_bytes = 0;  /* destination UTF-8 bytes count */
+  int dest_offset = 0; /* destination string unicode characters index */
+  unsigned char* p = dest;
+  
+  if(!src)
+    return 0;
+
+  while(src_length > 0) {
+    int unichar_len;
+
+    unichar_len = raptor_unicode_utf8_string_get_char(src, src_length, NULL);
+    if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > src_length)
+      break;
+
+    if(dest_offset >= startingLoc) {
+      if(p) {
+        /* copy 1 Unicode character to dest */
+        memcpy(p, src, RAPTOR_GOOD_CAST(size_t, unichar_len));
+        p += unichar_len;
+      }
+      dest_bytes += unichar_len;
+
+      dest_length++;
+      if(length >= 0 && dest_length == RAPTOR_GOOD_CAST(size_t, length))
+        break;
+    }
+
+    src += unichar_len;
+    src_length -= unichar_len;
+
+    dest_offset++;
+  }
+
+  if(p)
+    *p = '\0';
+
+  if(dest_length_p)
+    *dest_length_p = dest_length;
+
+  return dest_bytes;
+}
