@@ -41,6 +41,10 @@
 #ifdef HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
+/* for ptrdiff_t */
+#ifdef HAVE_STDDEF_H
+#include <stddef.h>
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
@@ -49,7 +53,7 @@
 #endif
 
 /* Raptor includes */
-#include "raptor.h"
+#include "raptor2.h"
 #include "raptor_internal.h"
 
 
@@ -117,7 +121,7 @@ raptor_new_uri_from_counted_string(raptor_world* world,
     memset(&key, 0, sizeof(key));
 
     key.string = (unsigned char*)uri_string;
-    key.length = length;
+    key.length = (unsigned int)length;
 
     /* if existing URI found in tree, return it */
     new_uri = (raptor_uri*)raptor_avltree_search(world->uris_tree, &key);
@@ -140,14 +144,14 @@ raptor_new_uri_from_counted_string(raptor_world* world,
   RAPTOR_DEBUG2("Creating new URI %s in hash\n", uri_string);
 #endif
 
-  new_uri = (raptor_uri*)RAPTOR_CALLOC(raptor_uri, 1, sizeof(*new_uri));
+  new_uri = RAPTOR_CALLOC(raptor_uri*, 1, sizeof(*new_uri));
   if(!new_uri)
     goto unlock;
 
   new_uri->world = world;
-  new_uri->length = length;
+  new_uri->length = (unsigned int)length;
 
-  new_string = (unsigned char*)RAPTOR_MALLOC(cstring, length + 1);
+  new_string = RAPTOR_MALLOC(unsigned char*, length + 1);
   if(!new_string) {
     RAPTOR_FREE(raptor_uri, new_uri);
     new_uri=NULL;
@@ -163,7 +167,7 @@ raptor_new_uri_from_counted_string(raptor_world* world,
   /* store in tree */
   if(world->uris_tree) {
     if(raptor_avltree_add(world->uris_tree, new_uri)) {
-      RAPTOR_FREE(cstring, new_string);
+      RAPTOR_FREE(char*, new_string);
       RAPTOR_FREE(raptor_uri, new_uri);
       new_uri = NULL;
     }
@@ -217,7 +221,7 @@ raptor_uri*
 raptor_new_uri_from_uri_local_name(raptor_world* world, raptor_uri *uri,
                                    const unsigned char *local_name)
 {
-  int len;
+  size_t len;
   unsigned char *new_string;
   raptor_uri* new_uri;
   size_t local_name_length;
@@ -232,7 +236,7 @@ raptor_new_uri_from_uri_local_name(raptor_world* world, raptor_uri *uri,
   local_name_length = strlen((const char*)local_name);
   
   len = uri->length + local_name_length;
-  new_string = (unsigned char*)RAPTOR_MALLOC(cstring, len + 1);
+  new_string = RAPTOR_MALLOC(unsigned char*, len + 1);
   if(!new_string)
     return NULL;
 
@@ -241,7 +245,7 @@ raptor_new_uri_from_uri_local_name(raptor_world* world, raptor_uri *uri,
          local_name_length + 1);
 
   new_uri = raptor_new_uri_from_counted_string(world, new_string, len);
-  RAPTOR_FREE(cstring, new_string);
+  RAPTOR_FREE(char*, new_string);
 
   return new_uri;
 }
@@ -263,7 +267,7 @@ raptor_new_uri_relative_to_base(raptor_world* world,
                                 const unsigned char *uri_string) 
 {
   unsigned char *buffer;
-  int buffer_length;
+  size_t buffer_length;
   raptor_uri* new_uri;
   size_t actual_length;
   
@@ -280,7 +284,7 @@ raptor_new_uri_relative_to_base(raptor_world* world,
   
   /* +1 for adding any missing URI path '/' */
   buffer_length = base_uri->length + strlen((const char*)uri_string) + 1;
-  buffer = (unsigned char*)RAPTOR_MALLOC(cstring, buffer_length + 1);
+  buffer = RAPTOR_MALLOC(unsigned char*, buffer_length + 1);
   if(!buffer)
     return NULL;
   
@@ -288,7 +292,7 @@ raptor_new_uri_relative_to_base(raptor_world* world,
                                                    buffer, buffer_length);
 
   new_uri = raptor_new_uri_from_counted_string(world, buffer, actual_length);
-  RAPTOR_FREE(cstring, buffer);
+  RAPTOR_FREE(char*, buffer);
   return new_uri;
 }
 
@@ -312,7 +316,7 @@ raptor_new_uri_from_id(raptor_world *world, raptor_uri *base_uri,
 {
   raptor_uri *new_uri;
   unsigned char *local_name;
-  int len;
+  size_t len;
 
   RAPTOR_CHECK_CONSTRUCTOR_WORLD(world);
 
@@ -327,7 +331,7 @@ raptor_new_uri_from_id(raptor_world *world, raptor_uri *base_uri,
 
   len = strlen((char*)id);
   /* "#id\0" */
-  local_name = (unsigned char*)RAPTOR_MALLOC(cstring, len + 1 + 1);
+  local_name = RAPTOR_MALLOC(unsigned char*, len + 1 + 1);
   if(!local_name)
     return NULL;
 
@@ -335,7 +339,7 @@ raptor_new_uri_from_id(raptor_world *world, raptor_uri *base_uri,
   memcpy(local_name + 1, id, len + 1); /* len+1 to copy NUL */
 
   new_uri = raptor_new_uri_relative_to_base(world, base_uri, local_name);
-  RAPTOR_FREE(cstring, local_name);
+  RAPTOR_FREE(char*, local_name);
   return new_uri;
 }
 
@@ -358,8 +362,8 @@ raptor_new_uri_for_rdf_concept(raptor_world* world, const unsigned char *name)
   raptor_uri *new_uri;
   unsigned char *new_uri_string;
   const unsigned char *base_uri_string = raptor_rdf_namespace_uri;
-  unsigned int base_uri_string_len = raptor_rdf_namespace_uri_len;
-  unsigned int new_uri_string_len;
+  size_t base_uri_string_len = raptor_rdf_namespace_uri_len;
+  size_t new_uri_string_len;
   size_t name_len;
   
   RAPTOR_CHECK_CONSTRUCTOR_WORLD(world);
@@ -371,8 +375,7 @@ raptor_new_uri_for_rdf_concept(raptor_world* world, const unsigned char *name)
 
   name_len = strlen((const char*)name);
   new_uri_string_len = base_uri_string_len + name_len;
-  new_uri_string = (unsigned char*)RAPTOR_MALLOC(cstring,
-                                                 new_uri_string_len + 1);
+  new_uri_string = RAPTOR_MALLOC(unsigned char*, new_uri_string_len + 1);
   if(!new_uri_string)
     return NULL;
 
@@ -381,7 +384,7 @@ raptor_new_uri_for_rdf_concept(raptor_world* world, const unsigned char *name)
 
   new_uri = raptor_new_uri_from_counted_string(world, new_uri_string,
                                                new_uri_string_len);
-  RAPTOR_FREE(cstring, new_uri_string);
+  RAPTOR_FREE(char*, new_uri_string);
   
   return new_uri;
 }
@@ -415,7 +418,7 @@ raptor_free_uri(raptor_uri *uri)
     raptor_avltree_delete(uri->world->uris_tree, uri);
 
   if(uri->string)
-    RAPTOR_FREE(cstring, uri->string);
+    RAPTOR_FREE(char*, uri->string);
   RAPTOR_FREE(raptor_uri, uri);
 }
 
@@ -621,6 +624,7 @@ raptor_uri_filename_to_uri_string(const char *filename)
     path = (char*)malloc(path_max);
     while(1) {
       /* malloc() failed or getcwd() succeeded */
+      errno = 0;
       if(!path || getcwd(path, path_max))
         break;
 
@@ -648,7 +652,7 @@ raptor_uri_filename_to_uri_string(const char *filename)
       len += 2; /* strlen(%xx)-1 */
   }
 
-  buffer = (unsigned char*)RAPTOR_MALLOC(cstring, len);
+  buffer = RAPTOR_MALLOC(unsigned char*, len);
   if(!buffer)
     goto path_done;
 
@@ -791,7 +795,7 @@ raptor_uri_uri_string_to_filename_fragment(const unsigned char *uri_string,
     return NULL;
   }
     
-  filename = (char*)RAPTOR_MALLOC(cstring, len + 1);
+  filename = RAPTOR_MALLOC(char*, len + 1);
   if(!filename) {
     raptor_free_uri_detail(ud);
     return NULL;
@@ -844,7 +848,7 @@ raptor_uri_uri_string_to_filename_fragment(const unsigned char *uri_string,
   if(fragment_p) {
     if(ud->fragment) {
       len = ud->fragment_len;
-      *fragment_p = (unsigned char*)RAPTOR_MALLOC(cstring, len + 1);
+      *fragment_p = RAPTOR_MALLOC(unsigned char*, len + 1);
       if(*fragment_p)
         memcpy(*fragment_p, ud->fragment, len + 1);
     } else
@@ -933,7 +937,7 @@ raptor_new_uri_for_xmlbase(raptor_uri* old_uri)
     return NULL;
   
   new_uri = raptor_new_uri(old_uri->world, new_uri_string);
-  RAPTOR_FREE(cstring, new_uri_string);
+  RAPTOR_FREE(char*, new_uri_string);
 
   return new_uri;
 }
@@ -979,7 +983,7 @@ raptor_new_uri_for_retrieval(raptor_uri* old_uri)
     return NULL;
   
   new_uri = raptor_new_uri(old_uri->world, new_uri_string);
-  RAPTOR_FREE(cstring, new_uri_string);
+  RAPTOR_FREE(char*, new_uri_string);
 
   return new_uri;
 }
@@ -991,8 +995,15 @@ raptor_uri_init(raptor_world* world)
   if(world->uri_interning && !world->uris_tree) {
     world->uris_tree = raptor_new_avltree((raptor_data_compare_handler)raptor_uri_compare,
                                           /* free */ NULL, 0);
-    if(!world->uris_tree)
-      RAPTOR_FATAL1("Failed to create URI avltree");
+    if(!world->uris_tree) {
+#ifdef RAPTOR_DEBUG
+      RAPTOR_FATAL1("Failed to create raptor URI avltree");
+#else
+      raptor_log_error(world, RAPTOR_LOG_LEVEL_ERROR, NULL,
+                       "Failed to create raptor URI avltree");
+#endif
+    }
+    
   }
 
   return 0;
@@ -1021,27 +1032,31 @@ raptor_uri_finish(raptor_world* world)
  * Return value: Length of the common base path
  **/
 
-static int 
-raptor_uri_path_common_base_length(const unsigned char *first_path, size_t first_path_len,
-                                   const unsigned char *second_path, size_t second_path_len)
+static size_t
+raptor_uri_path_common_base_length(const unsigned char *first_path,
+                                   size_t first_path_len,
+                                   const unsigned char *second_path,
+                                   size_t second_path_len)
 {
-  int common_len = 0;
+  ptrdiff_t common_len = 0;
   const unsigned char *cur_ptr = first_path;
   const unsigned char *prev_ptr = first_path;
   
-  /* Compare each path component of first_path and second_path until there is
-     a mismatch. Then return the length from the start of the path to the last
-     successful match. */
+  /* Compare each path component of first_path and second_path until
+   * there is a mismatch. Then return the length from the start of
+   * the path to the last successful match. 
+   */
   while((cur_ptr = (const unsigned char*)memchr(cur_ptr, '/', first_path_len))) {
     cur_ptr++;
-    if(strncmp((const char*)first_path+common_len,
-               (const char*)second_path+common_len, cur_ptr-prev_ptr))
+    if(strncmp((const char*)first_path + common_len,
+               (const char*)second_path + common_len, cur_ptr - prev_ptr))
       break;
 
     first_path_len -= cur_ptr - prev_ptr;
     prev_ptr = cur_ptr;
     common_len = prev_ptr - first_path;
   }
+
   return prev_ptr - first_path;
 }
 
@@ -1067,12 +1082,13 @@ raptor_uri_path_make_relative_path(const unsigned char *from_path, size_t from_p
                                    const unsigned char *suffix, size_t suffix_len,
                                    size_t *result_length_p)
 {
-  int common_len, cur_len, final_len, up_dirs = 0, to_dir_len = 0;
+  size_t common_len, cur_len, final_len, to_dir_len;
+  int up_dirs = 0;
   const unsigned char *cur_ptr, *prev_ptr;
   unsigned char *final_path, *final_path_cur;
 
   common_len = raptor_uri_path_common_base_length(from_path, from_path_len,
-                                                to_path, to_path_len);
+                                                  to_path, to_path_len);
   
   if(result_length_p)
     *result_length_p=0;
@@ -1102,7 +1118,7 @@ raptor_uri_path_make_relative_path(const unsigned char *from_path, size_t from_p
   
   /* Create the final relative path */
   final_len = up_dirs*3 + to_dir_len + suffix_len; /* 3 for each "../" */
-  final_path = (unsigned char*)RAPTOR_MALLOC(cstring, final_len + 1);
+  final_path = RAPTOR_MALLOC(unsigned char*, final_len + 1);
   if(!final_path)
     return NULL;
   *final_path=0;
@@ -1235,7 +1251,7 @@ raptor_uri_to_relative_counted_uri_string(raptor_uri *base_uri,
     reference_file_len = reference_detail->path_len -
                          (reference_file - reference_detail->path);
     
-    if(!strcmp((const char*)base_file, (const char*)reference_file)) {
+    if(!strcmp((const char*)base_detail->path, (const char*)reference_detail->path)) {
       /* If the file names are equal, don't put them in the relative URI */
       reference_file = NULL;
       reference_file_len = 0;
@@ -1258,7 +1274,7 @@ raptor_uri_to_relative_counted_uri_string(raptor_uri *base_uri,
       suffix_len++; /* add one char for the '#' */
     
     /* Assemble the suffix */
-    suffix = (unsigned char*)RAPTOR_MALLOC(cstring, suffix_len + 1);
+    suffix = RAPTOR_MALLOC(unsigned char*, suffix_len + 1);
     if(!suffix)
       goto err;
     cur_ptr = suffix;
@@ -1294,7 +1310,7 @@ raptor_uri_to_relative_counted_uri_string(raptor_uri *base_uri,
                                                   suffix,
                                                   suffix_len,
                                                   length_p);
-      RAPTOR_FREE(cstring, suffix);
+      RAPTOR_FREE(char*, suffix);
     }
   }
 
@@ -1303,7 +1319,7 @@ raptor_uri_to_relative_counted_uri_string(raptor_uri *base_uri,
   /* If result is NULL at this point, it means that we were unable to find a
      relative URI, so we'll return a full absolute URI instead. */
   if(!result) {
-    result = (unsigned char*)RAPTOR_MALLOC(cstring, reference_len + 1);
+    result = RAPTOR_MALLOC(unsigned char*, reference_len + 1);
     if(result) {
       if(reference_len)
         memcpy(result, reference_str, reference_len);
@@ -1352,19 +1368,22 @@ raptor_uri_to_relative_uri_string(raptor_uri *base_uri,
 int
 raptor_uri_print(const raptor_uri* uri, FILE *stream)
 {
-  int rc = 0;
+  size_t nwritten = 0;
   size_t len = 10;
   unsigned char *string = (unsigned char*)"(NULL URI)";
+  raptor_world* world = NULL;
   
-  if(uri)
+  if(uri) {
+    world = uri->world;
     string = raptor_uri_as_counted_string((raptor_uri*)uri, &len);
+  }
 
-  rc = fwrite(string, 1, len, stream);
-  if(rc != (int)len)
-    raptor_log_error_formatted(uri->world, RAPTOR_LOG_LEVEL_ERROR,
+  nwritten = fwrite(string, 1, len, stream);
+  if(nwritten != len)
+    raptor_log_error_formatted(world, RAPTOR_LOG_LEVEL_ERROR,
                                NULL, "fwrite failed - %s", strerror(errno));
 
-  return rc;
+  return (nwritten == len);
 }
 
 
@@ -1396,7 +1415,7 @@ raptor_uri_to_counted_string(raptor_uri *uri, size_t *len_p)
   if(!string)
     return NULL;
   
-  new_string = (unsigned char*)RAPTOR_MALLOC(cstring, len + 1); /* +1 for NULL termination */
+  new_string = RAPTOR_MALLOC(unsigned char*, len + 1); /* +1 for NULL termination */
   if(!new_string)
     return NULL;
   
@@ -1438,11 +1457,17 @@ raptor_uri_to_string(raptor_uri *uri)
 raptor_uri*
 raptor_new_uri_from_rdf_ordinal(raptor_world* world, int ordinal)
 {
-  /* 55 = strlen(rdf namespace URI) + _ + 10-digit number + \0 */
-  unsigned char uri_string[55];
-  memcpy(uri_string, raptor_rdf_namespace_uri, raptor_rdf_namespace_uri_len);
-  sprintf((char*)uri_string+raptor_rdf_namespace_uri_len, "_%d",
-          ordinal);
+  /* strlen(rdf namespace URI) + _ + decimal int number + \0 */
+  unsigned char uri_string[43 + 1 + MAX_ASCII_INT_SIZE + 1];
+  unsigned char *p = uri_string;
+
+  memcpy(p, raptor_rdf_namespace_uri, raptor_rdf_namespace_uri_len);
+  p += raptor_rdf_namespace_uri_len;
+  *p++ = '_';
+  (void)raptor_format_integer(RAPTOR_GOOD_CAST(char*, p),
+                              MAX_ASCII_INT_SIZE + 1, ordinal, /* base */ 10,
+                              -1, '\0');
+
   return raptor_new_uri(world, uri_string);
 }
 
@@ -1503,11 +1528,11 @@ assert_filename_to_uri (const char *filename, const char *reference_uri)
             "%s: raptor_uri_filename_to_uri_string(%s) FAILED gaving URI %s != %s\n",
             program, filename, uri, reference_uri);
     if(uri)
-      RAPTOR_FREE(cstring, uri);
+      RAPTOR_FREE(char*, uri);
     return 1;
   }
 
-  RAPTOR_FREE(cstring, uri);
+  RAPTOR_FREE(char*, uri);
   return 0;
 }
 
@@ -1524,18 +1549,18 @@ assert_uri_to_filename (const char *uri, const char *reference_filename)
             "%s: raptor_uri_uri_string_to_filename(%s) FAILED giving filename %s != NULL\n", 
             program, uri, filename);
     if(filename)
-      RAPTOR_FREE(cstring, filename);
+      RAPTOR_FREE(char*, filename);
     return 1;
   } else if(filename && strcmp(filename, reference_filename)) {
     fprintf(stderr,
             "%s: raptor_uri_uri_string_to_filename(%s) FAILED gaving filename %s != %s\n",
             program, uri, filename, reference_filename);
     if(filename)
-      RAPTOR_FREE(cstring, filename);
+      RAPTOR_FREE(char*, filename);
     return 1;
   }
 
-  RAPTOR_FREE(cstring, filename);
+  RAPTOR_FREE(char*, filename);
   return 0;
 }
 
@@ -1568,10 +1593,10 @@ assert_uri_to_relative(raptor_world *world, const char *base, const char *uri, c
     fprintf(stderr,
             "%s: raptor_uri_string_to_relative_uri_string FAILED: base='%s', uri='%s', expected='%s', got='%s'\n",
             program, base, uri, relative, output);
-    RAPTOR_FREE(cstring, output);
+    RAPTOR_FREE(char*, output);
     return 1;
   }
-  RAPTOR_FREE(cstring, output);
+  RAPTOR_FREE(char*, output);
   if(base_uri)
     raptor_free_uri(base_uri);
   raptor_free_uri(reference_uri);
@@ -1663,7 +1688,7 @@ main(int argc, char *argv[])
             program);
   else {
     sprintf((char*)uri_buffer, "file://%s/foo", dir);
-#if RAPTOR_DEBUG > 1
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1
     fprintf(stderr,
             "%s: Checking relative file name 'foo' in dir %s expecting URI %s\n",
             program, dir, uri_buffer);
@@ -1717,6 +1742,7 @@ main(int argc, char *argv[])
   failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example.com/base/foo/bar", "foo/bar");
   failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example.com/base/foo#bar", "#bar");
   failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example.com/base/bar#foo", "bar#foo");
+  failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example.com/otherbase/foo", "../otherbase/foo");
   failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example.com/otherbase/bar", "../otherbase/bar");
   failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example.com/base/#foo", ".#foo");
   failures += assert_uri_to_relative(world, "http://example.com/base/foo", "http://example2.com/base/bar", "http://example2.com/base/bar");
