@@ -67,8 +67,7 @@ raptor_new_xml_element(raptor_qname *name,
 {
   raptor_xml_element* xml_element;
 
-  xml_element = (raptor_xml_element*)RAPTOR_CALLOC(raptor_xml_element, 1,
-                                                   sizeof(*xml_element));
+  xml_element = RAPTOR_CALLOC(raptor_xml_element*, 1, sizeof(*xml_element));
   if(!xml_element)
     return NULL;
 
@@ -155,7 +154,7 @@ raptor_free_xml_element(raptor_xml_element *element)
     raptor_free_uri(element->base_uri);
 
   if(element->xml_language)
-    RAPTOR_FREE(cstring, (void*)element->xml_language);
+    RAPTOR_FREE(char*, element->xml_language);
 
   raptor_free_qname(element->name);
 
@@ -360,8 +359,8 @@ raptor_xml_element_write(raptor_xml_element *element,
     if(element->declared_nspaces)
       nspace_max_count += raptor_sequence_size(element->declared_nspaces);
     
-    nspace_declarations = (struct nsd*)RAPTOR_CALLOC(nsdarray, nspace_max_count,
-                                                     sizeof(struct nsd));
+    nspace_declarations = RAPTOR_CALLOC(struct nsd*, nspace_max_count,
+                                        sizeof(struct nsd));
   }
 
   if(element->name->nspace) {
@@ -459,7 +458,7 @@ raptor_xml_element_write(raptor_xml_element *element,
       raptor_iostream_counted_string_write((const char*)nspace_declarations[i].declaration,
                                            nspace_declarations[i].length,
                                            iostr);
-      RAPTOR_FREE(cstring, nspace_declarations[i].declaration);
+      RAPTOR_FREE(char*, nspace_declarations[i].declaration);
       nspace_declarations[i].declaration = NULL;
 
       raptor_namespace_stack_start_namespace(nstack,
@@ -539,7 +538,7 @@ raptor_xml_element_get_language(raptor_xml_element* xml_element)
 int
 raptor_valid_xml_ID(raptor_parser *rdf_parser, const unsigned char *string)
 {
-  int len = strlen((const char*)string);
+  size_t len = strlen((const char*)string);
 #ifdef RAPTOR_XML_1_1
   #define XML_ID_XML_VERSION 11
 #else
@@ -602,7 +601,7 @@ raptor_xml_escape_string_any(raptor_world *world,
                              char quote,
                              int xml_version)
 {
-  int l;
+  size_t l;
   size_t new_len = 0;
   const unsigned char *p;
   unsigned char *q;
@@ -622,7 +621,7 @@ raptor_xml_escape_string_any(raptor_world *world,
   for(l = len, p = string; l; p++, l--) {
     if(*p > 0x7f) {
       unichar_len = raptor_unicode_utf8_string_get_char(p, l, &unichar);
-      if(unichar_len < 0 || unichar_len > l) {
+      if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > l) {
         raptor_log_error(world, RAPTOR_LOG_LEVEL_ERROR, NULL,
                          "Bad UTF-8 encoding.");
         return -1;
@@ -668,11 +667,12 @@ raptor_xml_escape_string_any(raptor_world *world,
     return 0;
 
   if(!buffer)
-    return new_len;
+    return RAPTOR_BAD_CAST(int, new_len);
   
   for(l = len, p = string, q = buffer; l; p++, l--) {
     if(*p > 0x7f) {
       unichar_len = raptor_unicode_utf8_string_get_char(p, l, &unichar);
+      /* if the UTF-8 encoding is bad, we already did return -1 above */
     } else {
       unichar=*p;
       unichar_len = 1;
@@ -712,12 +712,13 @@ raptor_xml_escape_string_any(raptor_world *world,
                                    unichar);
       } else {
         /* &#xX; */
-        *q++='&';
-        *q++='#';
-        *q++='x';
-        sprintf((char*)q, "%X", (unsigned int)unichar);
-        q+= (unichar < 0x10) ? 1 : 2;
-        *q++=';';
+        *q++ = '&';
+        *q++ = '#';
+        *q++ = 'x';
+        q += raptor_format_integer((char*)q, 3, 
+                                   RAPTOR_GOOD_CAST(unsigned int, unichar), 
+                                   /* base */ 16, -1, '\0');
+        *q++ = ';';
       }
     } else {
       memcpy(q, p, unichar_len);
@@ -731,7 +732,7 @@ raptor_xml_escape_string_any(raptor_world *world,
   /* Terminate new string */
   *q = '\0';
 
-  return new_len;
+  return RAPTOR_BAD_CAST(int, new_len);
 }
 
 
@@ -793,7 +794,7 @@ raptor_xml_escape_string_any_write(const unsigned char *string,
                                     int xml_version,
                                     raptor_iostream* iostr)
 {
-  int l;
+  size_t l;
   const unsigned char *p;
 
   if(xml_version != 10)
@@ -808,7 +809,7 @@ raptor_xml_escape_string_any_write(const unsigned char *string,
 
     if(*p > 0x7f) {
       unichar_len = raptor_unicode_utf8_string_get_char(p, l, &unichar);
-      if(unichar_len < 0 || unichar_len > l) {
+      if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > l) {
         raptor_log_error(raptor_iostream_get_world(iostr),
                          RAPTOR_LOG_LEVEL_ERROR, NULL,
                          "Bad UTF-8 encoding.");
@@ -848,7 +849,7 @@ raptor_xml_escape_string_any_write(const unsigned char *string,
 
         /* &#xX; */
         raptor_iostream_counted_string_write("&#x", 3, iostr);
-        raptor_iostream_hexadecimal_write(unichar, width, iostr);
+        raptor_iostream_hexadecimal_write(RAPTOR_GOOD_CAST(unsigned int, unichar), width, iostr);
         raptor_iostream_write_byte(';', iostr);
       }
     } else
@@ -914,7 +915,7 @@ raptor_xml_name_check(const unsigned char *string, size_t length,
 
     int unichar_len;
     unichar_len = raptor_unicode_utf8_string_get_char(string, length, &unichar);
-    if(unichar_len < 0 || unichar_len > (int)length)
+    if(unichar_len < 0 || RAPTOR_GOOD_CAST(size_t, unichar_len) > length)
       return 0;
 
     if(unichar > raptor_unicode_max_codepoint)
@@ -1051,7 +1052,7 @@ main(int argc, char *argv[])
       continue;
     }
       
-    xml_string = (unsigned char*)RAPTOR_MALLOC(cstring, xml_string_len+1);
+    xml_string = RAPTOR_MALLOC(unsigned char*, xml_string_len + 1);
     
     xml_string_len = raptor_xml_escape_string(world,
                                               utf8_string, utf8_string_len,
@@ -1074,14 +1075,14 @@ main(int argc, char *argv[])
       continue;
     }
 
-#if RAPTOR_DEBUG > 1    
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1    
     fprintf(stderr, "%s: raptor_xml_escape_string escaped string to '%s' ok\n",
             program, xml_string);
 #endif
-    RAPTOR_FREE(cstring, xml_string);
+    RAPTOR_FREE(char*, xml_string);
   }
 
-#if RAPTOR_DEBUG > 1    
+#if defined(RAPTOR_DEBUG) && RAPTOR_DEBUG > 1    
   if(!failures)
     fprintf(stderr, "%s: raptor_xml_escape_string all tests OK\n", program);
 #endif
